@@ -47,6 +47,7 @@
 #include "ailog.h"
 #include "aitools.h"
 #include "aiunit.h"
+#include "daimilitary.h"
 
 #include "aiair.h"
 
@@ -74,7 +75,7 @@ static inline int regen_turns(struct unit *punit, struct tile *ptile,
   return res;
 }
 /**************************************************************************
-  Looks for nearest airbase for punit reachable imediatly.
+  Looks for nearest airbase for punit reachable immediately.
   Returns NULL if not found.  The path is stored in the path
   argument if not NULL.
   If the unit is damaged, flies to an airbase that can repair
@@ -578,7 +579,8 @@ bool dai_choose_attacker_air(struct ai_type *ait, struct player *pplayer,
 
   /* military_advisor_choose_build does something idiotic, 
    * this function should not be called if there is danger... */
-  if (choice->want >= 100 && choice->type != CT_ATTACKER) {
+  if (choice->want >= DAI_WANT_MILITARY_EMERGENCY
+      && choice->type != CT_ATTACKER) {
     return FALSE;
   }
 
