@@ -311,7 +311,8 @@ static void dai_hunter_try_launch(struct ai_type *ait,
   struct pf_parameter parameter;
   struct pf_map *pfm;
 
-  unit_list_iterate_safe(unit_tile(punit)->units, missile) {
+  /* Only directly transported units. Not launching cargo of cargo */
+  unit_list_iterate_safe(punit->transporting, missile) {
     struct unit *sucker = NULL;
 
     if (unit_owner(missile) == pplayer
@@ -363,6 +364,7 @@ static void dai_hunter_try_launch(struct ai_type *ait,
         }
       } pf_map_move_costs_iterate_end;
       pf_map_destroy(pfm);
+
       if (sucker) {
         if (unit_transported(missile)) {
           unit_transport_unload_send(missile);
@@ -376,8 +378,9 @@ static void dai_hunter_try_launch(struct ai_type *ait,
             dai_unit_attack(ait, missile, unit_tile(sucker));
           }
         }
-        target = game_unit_by_number(target_sanity); /* Sanity */
-        break; /* try next missile, if any */
+        if (game_unit_by_number(target_sanity) == NULL) {
+          return; /* Target killed */
+        }
       }
     } /* if */
   } unit_list_iterate_safe_end;
