@@ -374,13 +374,13 @@ void dai_log_path(struct unit *punit,
                   struct pf_path *path, struct pf_parameter *parameter)
 {
   const struct pf_position *last = pf_path_last_position(path);
-  const int cc = PF_TURN_FACTOR * last->total_MC
-                 + parameter->move_rate * last->total_EC;
-  const int tc = cc / (PF_TURN_FACTOR *parameter->move_rate); 
+  const unsigned cc = PF_TURN_FACTOR * last->total_MC
+    + parameter->move_rate * last->total_EC;
+  const unsigned tc = cc / (PF_TURN_FACTOR * parameter->move_rate);
 
-  UNIT_LOG(LOG_DEBUG, punit, "path L=%d T=%d(%d) MC=%d EC=%d CC=%d",
-	   path->length - 1, last->turn, tc,
-	   last->total_MC, last->total_EC, cc);
+  UNIT_LOG(LOG_DEBUG, punit, "path L=%d T=%d(%u) MC=%u EC=%u CC=%u",
+           path->length - 1, last->turn, tc,
+           last->total_MC, last->total_EC, cc);
 }
 
 /**************************************************************************
@@ -1068,7 +1068,7 @@ void dai_build_adv_override(struct ai_type *ait, struct city *pcity,
                             struct adv_choice *choice)
 {
   struct impr_type *chosen;
-  int want;
+  adv_want want;
 
   if (choice->type == CT_NONE) {
     want = 0;
@@ -1081,9 +1081,11 @@ void dai_build_adv_override(struct ai_type *ait, struct city *pcity,
   improvement_iterate(pimprove) {
     /* Advisor code did not consider wonders, let's do it here */
     if (is_wonder(pimprove)) {
-      if (pcity->server.adv->building_want[improvement_index(pimprove)] > want
+      int id = improvement_index(pimprove);
+
+      if (pcity->server.adv->building_want[id] > want
           && can_city_build_improvement_now(pcity, pimprove)) {
-        want = pcity->server.adv->building_want[improvement_index(pimprove)];
+        want = pcity->server.adv->building_want[id];
         chosen = pimprove;
       }
     }
@@ -1095,9 +1097,9 @@ void dai_build_adv_override(struct ai_type *ait, struct city *pcity,
   if (chosen) {
     choice->type = CT_BUILDING; /* In case advisor had not chosen anything */
 
-    CITY_LOG(LOG_DEBUG, pcity, "ai wants most to build %s at %d",
-             improvement_rule_name(chosen),
-             want);
+    CITY_LOG(LOG_DEBUG, pcity, "AI wants to build %s with want "
+             ADV_WANT_PRINTF,
+             improvement_rule_name(chosen), want);
   }
 }
 
