@@ -1132,12 +1132,13 @@ static void suggest_tech_exchange(struct ai_type *ait,
 {
   struct research *presearch1 = research_get(player1);
   struct research *presearch2 = research_get(player2);
-  int worth[advance_count()];
+  Tech_type_id ac = advance_count();
+  int worth[ac];
   bool is_dangerous;
-    
+
   worth[A_NONE] = 0;
 
-  advance_index_iterate(A_FIRST, tech) {
+  advance_index_iterate_max(A_FIRST, tech, ac) {
     if (research_invention_state(presearch1, tech)
         == TECH_KNOWN) {
       if (research_invention_state(presearch2, tech) != TECH_KNOWN
@@ -1145,7 +1146,7 @@ static void suggest_tech_exchange(struct ai_type *ait,
         worth[tech] = -compute_tech_sell_price(ait, player1, player2, tech,
 	                                       &is_dangerous);
 	if (is_dangerous) {
-	  /* don't try to exchange */
+	  /* Don't try to exchange */
 	  worth[tech] = 0;
 	}
       } else {
@@ -1158,20 +1159,20 @@ static void suggest_tech_exchange(struct ai_type *ait,
         worth[tech] = compute_tech_sell_price(ait, player2, player1, tech,
 	                                      &is_dangerous);
 	if (is_dangerous) {
-	  /* don't try to exchange */
+	  /* Don't try to exchange */
 	  worth[tech] = 0;
 	}
       } else {
         worth[tech] = 0;
       }
     }
-  } advance_index_iterate_end;
-    
-  advance_index_iterate(A_FIRST, tech) {
+  } advance_index_iterate_max_end;
+
+  advance_index_iterate_max(A_FIRST, tech, ac) {
     if (worth[tech] <= 0) {
       continue;
     }
-    advance_index_iterate(A_FIRST, tech2) {
+    advance_index_iterate_max(A_FIRST, tech2, ac) {
       int diff;
 
       if (worth[tech2] >= 0) {
@@ -1181,18 +1182,18 @@ static void suggest_tech_exchange(struct ai_type *ait,
       diff = worth[tech] + worth[tech2];
       if ((diff > 0 && player1->economic.gold >= diff)
           || (diff < 0 && player2->economic.gold >= -diff)
-	  || diff == 0) {
+          || diff == 0) {
         dai_diplomacy_suggest(player1, player2, CLAUSE_ADVANCE, FALSE, tech2);
-	dai_diplomacy_suggest(player1, player2, CLAUSE_ADVANCE, TRUE, tech);
-	if (diff > 0) {
+        dai_diplomacy_suggest(player1, player2, CLAUSE_ADVANCE, TRUE, tech);
+        if (diff > 0) {
           dai_diplomacy_suggest(player1, player2, CLAUSE_GOLD, FALSE, diff);
-	} else if (diff < 0) {
+        } else if (diff < 0) {
           dai_diplomacy_suggest(player1, player2, CLAUSE_GOLD, TRUE, -diff);
-	}
-	return;
+        }
+        return;
       }
-    } advance_index_iterate_end;
-  } advance_index_iterate_end;
+    } advance_index_iterate_max_end;
+  } advance_index_iterate_max_end;
 }
 
 /********************************************************************** 
@@ -1356,6 +1357,7 @@ static void dai_go_to_war(struct ai_type *ait, struct player *pplayer,
     } else {
       /* There would be Senate even during revolution. Better not to revolt for nothing */
       pplayer->government = real_gov;
+      adip->countdown = -1; /* War declaration aborted */
 
       DIPLO_LOG(ait, LOG_DEBUG, pplayer, target,
                 "Not revolting, as there would be Senate regardless.");
@@ -1369,6 +1371,8 @@ static void dai_go_to_war(struct ai_type *ait, struct player *pplayer,
     if (pplayer_can_cancel_treaty(pplayer, target) != DIPL_OK) {
       DIPLO_LOG(ait, LOG_ERROR, pplayer, target,
                 "Wanted to cancel treaty but was unable to.");
+      adip->countdown = -1; /* War declaration aborted */
+
       return;
     }
     handle_diplomacy_cancel_pact(pplayer, player_number(target), clause_type_invalid());
@@ -1570,6 +1574,7 @@ void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer)
           || pplayers_at_war(pplayer, aplayer)) {
         continue;
       }
+
       /* A spaceship victory is always one single player's or team's victory */
       if (aplayer->spaceship.state == SSHIP_LAUNCHED
           && adv->dipl.spacerace_leader == aplayer
@@ -1579,15 +1584,15 @@ void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer)
                            "yourself alone betrays your true intentions, and I "
                            "will have no more of our alliance!"),
                          player_name(pplayer));
-	handle_diplomacy_cancel_pact(pplayer, player_number(aplayer),
-				     CLAUSE_ALLIANCE);
+        handle_diplomacy_cancel_pact(pplayer, player_number(aplayer),
+                                     CLAUSE_ALLIANCE);
         if (gives_shared_vision(pplayer, aplayer)) {
           remove_shared_vision(pplayer, aplayer);
         }
         /* Never forgive this */
         pplayer->ai_common.love[player_index(aplayer)] = -MAX_AI_LOVE;
       } else if (ship->state == SSHIP_STARTED 
-		 && adip->warned_about_space == 0) {
+                 && adip->warned_about_space == 0) {
         pplayer->ai_common.love[player_index(aplayer)] -= MAX_AI_LOVE / 10;
         adip->warned_about_space = 10 + fc_rand(6);
         dai_diplo_notify(aplayer,
@@ -1677,22 +1682,24 @@ void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer)
   /*** Actually declare war (when we have moved units into position) ***/
 
   players_iterate(aplayer) {
-    struct ai_dip_intel *adip = dai_diplomacy_get(ait, pplayer, aplayer);
+    if (!players_on_same_team(pplayer, aplayer)) {
+      struct ai_dip_intel *adip = dai_diplomacy_get(ait, pplayer, aplayer);
 
-    if (!aplayer->is_alive) {
-      adip->countdown = -1;
-      continue;
-    }
-    if (adip->countdown > 0) {
-      adip->countdown--;
-    } else if (adip->countdown == 0) {
-      if (!WAR(pplayer, aplayer)) {
-        DIPLO_LOG(ait, LOG_DIPL2, pplayer, aplayer, "Declaring war!");
-        dai_go_to_war(ait, pplayer, aplayer, adip->war_reason);
+      if (!aplayer->is_alive) {
+        adip->countdown = -1;
+        continue;
+      }
+      if (adip->countdown > 0) {
+        adip->countdown--;
+      } else if (adip->countdown == 0) {
+        if (!WAR(pplayer, aplayer)) {
+          DIPLO_LOG(ait, LOG_DIPL2, pplayer, aplayer, "Declaring war!");
+          dai_go_to_war(ait, pplayer, aplayer, adip->war_reason);
+        }
+      } else if (adip->countdown < -1) {
+        /* Negative countdown less than -1 is war stubbornness */
+        adip->countdown++;
       }
-    } else if (adip->countdown < -1) {
-      /* negative countdown less than -1 is war stubbornness */
-      adip->countdown++;
     }
   } players_iterate_end;
 
@@ -1713,7 +1720,8 @@ void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer)
       if (gives_shared_vision(pplayer, aplayer)) {
         if (!pplayers_allied(pplayer, aplayer)) {
           remove_shared_vision(pplayer, aplayer);
-        } else if (!shared_vision_is_safe(pplayer, aplayer)) {
+        } else if (!players_on_same_team(pplayer, aplayer)
+                   && !shared_vision_is_safe(pplayer, aplayer)) {
           dai_diplo_notify(aplayer,
                            _("*%s (AI)* Sorry, sharing vision with you "
                              "is no longer safe."),
@@ -1801,26 +1809,27 @@ void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer)
                                player_name(target));
               adip->ally_patience--;
             }
-          } else {
-            if (fc_rand(5) == 1) {
-              dai_diplo_notify(aplayer,
-                               _("*%s (AI)* Dishonored one, we made a pact of "
-                                 "alliance, and yet you remain at peace with our mortal "
-                                 "enemy, %s! This is unacceptable; our alliance is no "
-                                 "more!"),
-                               player_name(pplayer),
-                               player_name(target));
-              DIPLO_LOG(ait, LOG_DIPL2, pplayer, aplayer, "breaking useless alliance");
-              /* to peace */
-              handle_diplomacy_cancel_pact(pplayer, player_number(aplayer),
-                                           CLAUSE_ALLIANCE);
-              pplayer->ai_common.love[player_index(aplayer)] =
-                MIN(pplayer->ai_common.love[player_index(aplayer)], 0);
-              if (gives_shared_vision(pplayer, aplayer)) {
-                remove_shared_vision(pplayer, aplayer);
-              }
-              fc_assert(!gives_shared_vision(pplayer, aplayer));
+          } else if (fc_rand(5) == 1
+                     && !players_on_same_team(pplayer, aplayer)) {
+            dai_diplo_notify(aplayer,
+                             _("*%s (AI)* Dishonored one, we made a pact of "
+                               "alliance, and yet you remain at peace with our mortal "
+                               "enemy, %s! This is unacceptable; our alliance is no "
+                               "more!"),
+                             player_name(pplayer),
+                             player_name(target));
+            DIPLO_LOG(ait, LOG_DIPL2, pplayer, aplayer,
+                      "breaking useless alliance");
+            /* To peace */
+            handle_diplomacy_cancel_pact(pplayer, player_number(aplayer),
+                                         CLAUSE_ALLIANCE);
+            pplayer->ai_common.love[player_index(aplayer)]
+              = MIN(pplayer->ai_common.love[player_index(aplayer)], 0);
+            if (gives_shared_vision(pplayer, aplayer)) {
+              remove_shared_vision(pplayer, aplayer);
             }
+
+            fc_assert(!gives_shared_vision(pplayer, aplayer));
           }
         }
         break;
@@ -1928,7 +1937,7 @@ void dai_incident(struct ai_type *ait, enum incident_type type,
       dai_incident_nuclear_self(violator, victim);
       break;
     case INCIDENT_LAST:
-      /* Assert that always fails, but with meaningfull message */
+      /* Assert that always fails, but with meaningful message */
       fc_assert(type != INCIDENT_LAST);
       break;
   }
