@@ -76,6 +76,11 @@
 
 static unsigned int assess_danger(struct ai_type *ait, struct city *pcity);
 
+static adv_want dai_unit_attack_desirability(struct ai_type *ait,
+                                             const struct unit_type *punittype);
+static adv_want dai_unit_defense_desirability(struct ai_type *ait,
+                                              const struct unit_type *punittype);
+
 /**************************************************************************
   Choose the best unit the city can build to defend against attacker v.
 **************************************************************************/
@@ -113,7 +118,8 @@ struct unit_type *dai_choose_defender_versus(struct city *pcity,
                TILE_XY(attacker->tile), want);
 #endif /* NEVER */
 
-      if (want > best || (want == best && cost <= best_cost)) {
+      if (want > best || (ADV_WANTS_EQ(want, best)
+                          && cost <= best_cost)) {
         best = want;
         bestunit = punittype;
         best_cost = cost;
@@ -134,8 +140,8 @@ static struct unit_type *dai_choose_attacker(struct ai_type *ait, struct city *p
                                              enum terrain_class tc, bool allow_gold_upkeep)
 {
   struct unit_type *bestid = NULL;
-  int best = -1;
-  int cur;
+  adv_want best = -1;
+  adv_want cur;
   struct player *pplayer = city_owner(pcity);
 
   simple_ai_unit_type_iterate(putype) {
@@ -149,7 +155,7 @@ static struct unit_type *dai_choose_attacker(struct ai_type *ait, struct city *p
             && utype_class(putype)->adv.sea_move != MOVE_NONE)) {
       if (can_city_build_unit_now(pcity, putype)
           && (cur > best
-              || (cur == best
+              || (ADV_WANTS_EQ(cur, best)
                   && utype_build_shield_cost(putype)
                      <= utype_build_shield_cost(bestid)))) {
         best = cur;
@@ -176,7 +182,7 @@ static struct unit_type *dai_choose_bodyguard(struct ai_type *ait,
                                               bool allow_gold_upkeep)
 {
   struct unit_type *bestid = NULL;
-  int best = 0;
+  adv_want best = 0;
   struct player *pplayer = city_owner(pcity);
 
   simple_ai_unit_type_iterate(putype) {
@@ -200,11 +206,11 @@ static struct unit_type *dai_choose_bodyguard(struct ai_type *ait,
 
     /* Now find best */
     if (can_city_build_unit_now(pcity, putype)) {
-      const int desire = dai_unit_defense_desirability(ait, putype);
+      const adv_want desire = dai_unit_defense_desirability(ait, putype);
 
       if (desire > best
-	  || (desire == best && utype_build_shield_cost(putype) <=
-	      utype_build_shield_cost(bestid))) {
+          || (ADV_WANTS_EQ(desire, best) && utype_build_shield_cost(putype) <=
+              utype_build_shield_cost(bestid))) {
         best = desire;
         bestid = putype;
       }
@@ -215,7 +221,7 @@ static struct unit_type *dai_choose_bodyguard(struct ai_type *ait,
 }
 
 /********************************************************************** 
-Helper for assess_defense_quadratic and assess_defense_unit.
+  Helper for assess_defense_quadratic() and assess_defense_unit().
 ***********************************************************************/
 static int base_assess_defense_unit(struct city *pcity, struct unit *punit,
                                     bool igwall, bool quadratic,
@@ -662,10 +668,10 @@ static unsigned int assess_danger(struct ai_type *ait, struct city *pcity)
   How much we would want that unit to defend a city? (Do not use this 
   function to find bodyguards for ships or air units.)
 **************************************************************************/
-int dai_unit_defense_desirability(struct ai_type *ait,
-                                  const struct unit_type *punittype)
+static adv_want dai_unit_defense_desirability(struct ai_type *ait,
+                                              const struct unit_type *punittype)
 {
-  int desire = punittype->hp;
+  adv_want desire = punittype->hp;
   int attack = punittype->attack_strength;
   int defense = punittype->defense_strength;
   int maxbonus = 0;
@@ -697,10 +703,10 @@ int dai_unit_defense_desirability(struct ai_type *ait,
 /************************************************************************** 
   How much we would want that unit to attack with?
 **************************************************************************/
-int dai_unit_attack_desirability(struct ai_type *ait,
-                                 const struct unit_type *punittype)
+static adv_want dai_unit_attack_desirability(struct ai_type *ait,
+                                             const struct unit_type *punittype)
 {
-  int desire = punittype->hp;
+  adv_want desire = punittype->hp;
   int attack = punittype->attack_strength;
   int defense = punittype->defense_strength;
 
@@ -712,7 +718,7 @@ int dai_unit_attack_desirability(struct ai_type *ait,
     desire += desire / 2;
   }
   if (utype_has_flag(punittype, UTYF_GAMELOSS)) {
-    desire /= 10; /* but might actually be worth it */
+    desire /= 10; /* But might actually be worth it */
   }
   if (utype_has_flag(punittype, UTYF_CITYBUSTER)) {
     desire += desire / 2;
@@ -723,6 +729,7 @@ int dai_unit_attack_desirability(struct ai_type *ait,
   if (punittype->adv.igwall) {
     desire += desire / 4;
   }
+
   return desire;
 }
 
@@ -800,7 +807,8 @@ bool dai_process_defender_want(struct ai_type *ait, struct player *pplayer,
         if ((best_unit_cost > limit_cost
              && build_cost < best_unit_cost)
             || ((desire > best ||
-                 (desire == best && build_cost <= best_unit_cost))
+                 (desire == best
+                  && build_cost <= best_unit_cost))
                 && (best_unit_type == NULL
                     /* In case all units are more expensive than limit_cost */
                     || limit_cost <= pcity->shield_stock + 40))) {
@@ -828,7 +836,8 @@ bool dai_process_defender_want(struct ai_type *ait, struct player *pplayer,
         /* Yes, there's some similarity with kill_desire(). */
         /* TODO: Explain what shield cost has to do with tech want. */
         tech_desire[utype_index(punittype)] =
-          (desire * total_want / (utype_build_shield_cost(punittype) + tech_cost));
+          (desire * total_want
+           / (utype_build_shield_cost(punittype) + tech_cost));
       }
     }
   } simple_ai_unit_type_iterate_end;
@@ -903,7 +912,7 @@ bool dai_process_defender_want(struct ai_type *ait, struct player *pplayer,
 ****************************************************************************/
 static void process_attacker_want(struct ai_type *ait,
                                   struct city *pcity,
-                                  int value,
+                                  adv_want value,
                                   struct unit_type *victim_unit_type,
                                   struct player *victim_player,
                                   int veteran, struct tile *ptile,
@@ -1114,7 +1123,8 @@ static void process_attacker_want(struct ai_type *ait,
 
             CITY_LOG(LOG_DEBUG, pcity, "overriding %s(" ADV_WANT_PRINTF
                      ") with %s(" ADV_WANT_PRINTF ")"
-                     " [attack=%d,value=%d,move_time=%d,vuln=%d,bcost=%d]",
+                     " [attack=%d,value=" ADV_WANT_PRINTF
+                     ",move_time=%d,vuln=%d,bcost=%d]",
                      utype_rule_name(best_choice->value.utype),
 		     best_choice->want,
                      utype_rule_name(punittype),
@@ -1150,23 +1160,26 @@ static void process_attacker_want(struct ai_type *ait,
 }
 
 /************************************************************************** 
-This function 
-1. receives (in myunit) a first estimate of what we would like to build.
-2. finds a potential victim for it.
-3. calculates the relevant stats of the victim.
-4. finds the best attacker for this type of victim (in process_attacker_want)
-5. if we still want to attack, records the best attacker in choice.
-If the target is overseas, the function might suggest building a ferry
-to carry a land attack unit, instead of the land attack unit itself.
+  This function
+  1. receives (in myunit) a first estimate of what we would like to build.
+  2. finds a potential victim for it.
+  3. calculates the relevant stats of the victim.
+  4. finds the best attacker for this type of victim
+     (in process_attacker_want() )
+  5. if we still want to attack, records the best attacker in choice.
+  If the target is overseas, the function might suggest building a ferry
+  to carry a land attack unit, instead of the land attack unit itself.
 **************************************************************************/
-static struct adv_choice *kill_something_with(struct ai_type *ait, struct player *pplayer,
-                                              struct city *pcity, struct unit *myunit,
+static struct adv_choice *kill_something_with(struct ai_type *ait,
+                                              struct player *pplayer,
+                                              struct city *pcity,
+                                              struct unit *myunit,
                                               struct adv_choice *choice)
 {
   /* Our attack rating (with reinforcements) */
   int attack;
   /* Benefit from fighting the target */
-  int benefit;
+  adv_want benefit;
   /* Defender of the target city/tile */
   struct unit *pdef; 
   struct unit_type *def_type;
@@ -1250,7 +1263,6 @@ static struct adv_choice *kill_something_with(struct ai_type *ait, struct player
                                           city_owner(acity), ptile, FALSE,
                                           pdef->veteran);
       if (vulnerability < m) {
-        vulnerability = m;
         benefit = unit_build_shield_cost(pdef);
         def_vet = pdef->veteran;
         def_type = unit_type_get(pdef);
@@ -1361,16 +1373,16 @@ static void dai_unit_consider_bodyguard(struct ai_type *ait,
                                         struct unit_type *punittype,
                                         struct adv_choice *choice)
 {
-  struct unit *virtualunit;
-  struct player *pplayer = city_owner(pcity);
-  struct unit *aunit = NULL;
-  struct city *acity = NULL;
-
-  virtualunit = unit_virtual_create(pplayer, pcity, punittype,
-                                    city_production_unit_veteran_level(pcity, punittype));
-
   if (choice->want < DAI_WANT_MILITARY_EMERGENCY) {
-    const adv_want want = look_for_charge(ait, pplayer, virtualunit, &aunit, &acity);
+    struct player *pplayer = city_owner(pcity);
+    struct unit *aunit = NULL;
+    struct city *acity = NULL;
+    struct unit *virtualunit
+      = unit_virtual_create(pplayer, pcity, punittype,
+                            city_production_unit_veteran_level(pcity,
+                                                               punittype));
+    const adv_want want = look_for_charge(ait, pplayer, virtualunit,
+                                          &aunit, &acity);
 
     if (want > choice->want) {
       choice->want = want;
@@ -1378,9 +1390,9 @@ static void dai_unit_consider_bodyguard(struct ai_type *ait,
       choice->type = CT_DEFENDER;
       adv_choice_set_use(choice, "bodyguard");
     }
-  }
 
-  unit_virtual_destroy(virtualunit);
+    unit_virtual_destroy(virtualunit);
+  }
 }
 
 /*********************************************************************
