@@ -964,7 +964,7 @@ static void goto_fill_parameter_full(struct goto_map *goto_map,
   case HOVER_GOTO:
   case HOVER_PATROL:
     if (goto_last_action == ACTION_NUKE) {
-      /* We only want targets reachable immediatly... */
+      /* We only want targets reachable immediately... */
       parameter->move_rate = 0;
       /* ...then we don't need to deal with dangers or refuel points. */
       parameter->is_pos_dangerous = NULL;
@@ -1036,11 +1036,9 @@ void goto_unit_killed(struct unit *punit)
 
   goto_map_unit_iterate(goto_maps, goto_map, ptest) {
     if (ptest == punit) {
-      goto_map_free(goto_map);
-      /* Still safe using goto_map pointer, as it is not used for 
-       * dereferencing, only as value. */
       goto_map_list_remove(goto_maps, goto_map);
-      /* stop now, links are gone! */
+      goto_map_free(goto_map);
+      /* Stop now, links are gone! */
       break;
     }
   } goto_map_unit_iterate_end;
@@ -1617,9 +1615,11 @@ void send_connect_route(enum unit_activity activity,
 
     memset(&p, 0, sizeof(p));
 
-    for (i = 0; i < goto_map->num_parts; i++) {
+    i = 0;
+    do {
       path = pf_path_concat(path, goto_map->parts[i].path);
-    }
+      i++;
+    } while (i < goto_map->num_parts);
 
     p.unit_id = punit->id;
     p.src_tile = tile_index(unit_tile(punit));
@@ -1739,8 +1739,9 @@ static bool order_demands_direction(enum unit_orders order, action_id act_id)
 
 /**************************************************************************
   Send the current goto route (i.e., the one generated via
-  HOVER_STATE) to the server.  The route might involve more than one
-  part if waypoints were used.  FIXME: danger paths are not supported.
+  HOVER_STATE) to the server. The route might involve more than one
+  part, if waypoints were used.
+  FIXME: danger paths are not supported.
 **************************************************************************/
 void send_goto_route(void)
 {
@@ -1756,9 +1757,11 @@ void send_goto_route(void)
       continue;
     }
 
-    for (i = 0; i < goto_map->num_parts; i++) {
+    i = 0;
+    do {
       path = pf_path_concat(path, goto_map->parts[i].path);
-    }
+      i++;
+    } while (i < goto_map->num_parts);
 
     clear_unit_orders(punit);
 
