@@ -1,4 +1,4 @@
-/***********************************************************************
+/********************************************************************** 
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,11 +15,10 @@
 
 #include <gtk/gtk.h>
 
-/* client */
 #include "colors_g.h"
 
 struct color {
-  GdkRGBA color;
+  GdkColor color;
 };
 
 enum Display_color_type {
@@ -28,4 +27,6 @@ enum Display_color_type {
 
 enum Display_color_type get_visual(void);
 
+size_t color_to_string(GdkColor *color, char *string, size_t length);
+
 #endif  /* FC__COLORS_H */
