@@ -32,7 +32,7 @@
 /* client */
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "colors.h"
 #include "gui_main.h"
 
@@ -43,8 +43,6 @@ static GList *dialog_list;
 
 static GtkSizeGroup *gui_action;
 
-static GtkCssProvider *dlg_tab_provider = NULL;
-
 
 /**************************************************************************
   Draw widget now
@@ -71,20 +69,16 @@ void set_relative_window_position(GtkWindow *ref, GtkWindow *w, int px, int py)
 }
 
 /**************************************************************************
-  Create new icon button with label
+  Create new stock button
 **************************************************************************/
-GtkWidget *icon_label_button_new(const gchar *icon_name,
-                                 const gchar *label_text)
+GtkWidget *gtk_stockbutton_new(const gchar *stock, const gchar *label_text)
 {
   GtkWidget *button;
   GtkWidget *image;
-
+  
   button = gtk_button_new_with_mnemonic(label_text);
-
-  if (icon_name != NULL) {
-    image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_BUTTON);
-    gtk_button_set_image(GTK_BUTTON(button), image);
-  }
+  image = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image(GTK_BUTTON(button), image);
 
   return button;
 }
@@ -431,10 +425,7 @@ static void gui_dialog_switch_page_handler(GtkNotebook *notebook,
   n = gtk_notebook_page_num(GTK_NOTEBOOK(dlg->v.tab.notebook), dlg->vbox);
 
   if (n == num) {
-    GtkStyleContext *context = gtk_widget_get_style_context(dlg->v.tab.label);
-
-    gtk_style_context_remove_class(context, "alert");
-    gtk_style_context_remove_class(context, "notice");
+    gtk_widget_override_color(dlg->v.tab.label, GTK_STATE_FLAG_NORMAL, NULL);
   }
 }
 
@@ -505,7 +496,7 @@ static gboolean click_on_tab_callback(GtkWidget* w,
   Sets pdlg to point to the dialog once it is create, Zeroes pdlg on
   dialog destruction.
   user_data will be passed through response function
-  check_top indicates if the layout deision should depend on the parent.
+  check_top indicates if the layout decision should depend on the parent.
 **************************************************************************/
 void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
                     gpointer user_data, bool check_top)
@@ -588,8 +579,8 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       label = gtk_label_new(NULL);
       gtk_widget_set_halign(label, GTK_ALIGN_START);
       gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-      gtk_widget_set_margin_start(label, 4);
-      gtk_widget_set_margin_end(label, 4);
+      gtk_widget_set_margin_left(label, 4);
+      gtk_widget_set_margin_right(label, 4);
       gtk_widget_set_margin_top(label, 0);
       gtk_widget_set_margin_bottom(label, 0);
       gtk_container_add(GTK_CONTAINER(hbox), label);
@@ -603,9 +594,9 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       gtk_widget_set_tooltip_text(button, buf);
       g_free(buf);
 
-      image = gtk_image_new_from_icon_name("window-close", GTK_ICON_SIZE_MENU);
-      gtk_widget_set_margin_start(image, 0);
-      gtk_widget_set_margin_end(image, 0);
+      image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+      gtk_widget_set_margin_left(image, 0);
+      gtk_widget_set_margin_right(image, 0);
       gtk_widget_set_margin_top(image, 0);
       gtk_widget_set_margin_bottom(image, 0);
       gtk_button_set_image(GTK_BUTTON(button), image);
@@ -624,9 +615,6 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
                          G_CALLBACK(gui_dialog_switch_page_handler), dlg);
       dlg->v.tab.child = vbox;
 
-      gtk_style_context_add_provider(gtk_widget_get_style_context(label),
-                                     GTK_STYLE_PROVIDER(dlg_tab_provider),
-                                     GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
       dlg->v.tab.label = label;
       dlg->v.tab.notebook = GTK_WIDGET(notebook);
 
@@ -671,7 +659,7 @@ static void action_widget_activated(GtkWidget *button, GtkWidget *vbox)
   Places a button into a dialog, taking care of setting up signals, etc.
 **************************************************************************/
 static void gui_dialog_pack_button(struct gui_dialog *dlg, GtkWidget *button,
-                                   int response)
+				   int response)
 {
   gint signal_id;
 
@@ -694,15 +682,30 @@ static void gui_dialog_pack_button(struct gui_dialog *dlg, GtkWidget *button,
 }
 
 /**************************************************************************
-  Adds a button to a dialog.
+  Adds a button to a dialog, allowing the choice of a special stock item.
 **************************************************************************/
-GtkWidget *gui_dialog_add_button(struct gui_dialog *dlg,
-                                 const char *icon_name,
-                                 const char *text, int response)
+GtkWidget *gui_dialog_add_stockbutton(struct gui_dialog *dlg,
+				      const char *stock,
+				      const char *text, int response)
 {
   GtkWidget *button;
 
-  button = icon_label_button_new(icon_name, text);
+  button = gtk_stockbutton_new(stock, text);
+  gtk_widget_set_can_default(button, TRUE);
+  gui_dialog_pack_button(dlg, button, response);
+
+  return button;
+}
+
+/**************************************************************************
+  Adds a button to a dialog.
+**************************************************************************/
+GtkWidget *gui_dialog_add_button(struct gui_dialog *dlg,
+				 const char *text, int response)
+{
+  GtkWidget *button;
+
+  button = gtk_button_new_from_stock(text);
   gtk_widget_set_can_default(button, TRUE);
   gui_dialog_pack_button(dlg, button, response);
 
@@ -843,9 +846,9 @@ void gui_dialog_present(struct gui_dialog *dlg)
 
       if (current != n) {
 	GtkWidget *label = dlg->v.tab.label;
+	GdkRGBA color = {.red = 1.0, .green = 0, .blue = 0, .alpha = 1.0};
 
-        gtk_style_context_add_class(gtk_widget_get_style_context(label),
-                                    "notice");
+	gtk_widget_override_color(label, GTK_STATE_FLAG_NORMAL, &color);
       }
     }
     break;
@@ -895,11 +898,9 @@ void gui_dialog_alert(struct gui_dialog *dlg)
 
       if (current != n) {
         GtkWidget *label = dlg->v.tab.label;
-        GtkStyleContext *context = gtk_widget_get_style_context(label);
+        GdkRGBA color = {.red = 0, .green = 0, .blue =1.0, .alpha = 1.0};
 
-        /* Have only alert - remove notice if it exist. */
-        gtk_style_context_remove_class(context, "notice");
-        gtk_style_context_add_class(context, "alert");
+        gtk_widget_override_color(label, GTK_STATE_FLAG_NORMAL, &color);
       }
     }
     break;
@@ -1138,23 +1139,5 @@ GtkTreeViewColumn *add_treeview_column(GtkWidget *view, const char *title,
   col = gtk_tree_view_column_new_with_attributes(title, rend, attr,
                                                  model_index, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
-
   return col;
 }
-
-/**************************************************************************
-  Prepare dialog tab style provider.
-**************************************************************************/
-void dlg_tab_provider_prepare(void)
-{
-  dlg_tab_provider = gtk_css_provider_new();
-
-  gtk_css_provider_load_from_data(dlg_tab_provider,
-                                  ".alert {\n"
-                                  "color: rgba(255, 0, 0, 255);\n"
-                                  "}\n"
-                                  ".notice {\n"
-                                  "color: rgba(0, 0, 255, 255);\n"
-                                  "}\n",
-                                  -1, NULL);
-}
