@@ -36,7 +36,7 @@
 #include "client_main.h"
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 #include "mapview.h"
@@ -245,17 +245,18 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   GtkWidget *shell, *notebook, *label, *sw, *view, *table;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
-  int i;
 
+  int i;
+ 
   pdialog = fc_malloc(sizeof(*pdialog));
   pdialog->pplayer = p;
-
+ 
   shell = gtk_dialog_new_with_buttons(NULL,
-                                      NULL,
-                                      0,
-                                      _("_Close"),
-                                      GTK_RESPONSE_CLOSE,
-                                      NULL);
+      NULL,
+      0,
+      GTK_STOCK_CLOSE,
+      GTK_RESPONSE_CLOSE,
+      NULL);
   pdialog->shell = shell;
   gtk_window_set_default_size(GTK_WINDOW(shell), 350, 350);
   setup_dialog(shell, toplevel);
@@ -644,6 +645,7 @@ void update_intel_wonder_dialog(struct player *p)
 
         if (wonder_is_built(p, impr)) {
           struct city *pcity = city_from_wonder(p, impr);
+
           if (pcity) {
             cityname = city_name_get(pcity);
           } else {
