@@ -1521,7 +1521,7 @@ void show_tech_gained_dialog(Tech_type_id tech)
   Show tileset error dialog. It's blocking as client will
   shutdown as soon as this function returns.
 *****************************************************************/
-void show_tileset_error(const char *tset_name, const char *msg)
+void show_tileset_error(bool fatal, const char *tset_name, const char *msg)
 {
   if (is_gui_up()) {
     GtkWidget *dialog;
@@ -1530,13 +1530,15 @@ void show_tileset_error(const char *tset_name, const char *msg)
       dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                       GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
                                       _("Tileset \"%s\" problem, "
-                                        "it's probably incompatible with the ruleset:\n%s"),
+                                        "it's probably incompatible with "
+                                        "the ruleset:\n%s"),
                                       tset_name, msg);
     } else {
       dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                       GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
                                       _("Tileset problem, "
-                                        "it's probably incompatible with the ruleset:\n%s"),
+                                        "it's probably incompatible with "
+                                        "the ruleset:\n%s"),
                                       msg);
     }
 
