@@ -79,6 +79,7 @@ static void apply_help_font(struct option *poption);
 static void apply_notify_font(struct option *poption);
 static void apply_sidebar(struct option *poption);
 static void apply_titlebar(struct option *poption);
+static void apply_fullscreen(struct option *poption);
 
 /****************************************************************************
   Return fc_client instance
@@ -129,9 +130,9 @@ static void print_usage()
 }
 
 /**************************************************************************
-  Search for gui-specic command line options, that are not handled by Qt
+  Search for gui-specific command line options, that are not handled by Qt
   (QApplication). Returns true iff program is to be executed, and not
-  to exit after showing the results from option parsing. 
+  to exit after showing the results from option parsing.
 **************************************************************************/
 static bool parse_options(int argc, char **argv)
 {
@@ -257,6 +258,8 @@ void qtg_options_extra_init()
                           apply_titlebar);
   option_var_set_callback(gui_qt_sidebar_left,
                           apply_sidebar);
+  option_var_set_callback(gui_qt_fullscreen,
+                          apply_fullscreen);
 #undef option_var_set_callback
 }
 
@@ -358,7 +361,7 @@ void qtg_real_focus_units_changed(void)
 }
 
 /****************************************************************************
-  Enqueue a callback to be called during an idle moment.  The 'callback'
+  Enqueue a callback to be called during an idle moment. The 'callback'
   function should be called sometimes soon, and passed the 'data' pointer
   as its data.
 ****************************************************************************/
@@ -477,6 +480,13 @@ void apply_city_font(option *poption)
   }
 }
 
+/**********************************************************************//**
+  Applies fullscreen changes
+**************************************************************************/
+static void apply_fullscreen(struct option *poption)
+{
+  gui()->apply_fullscreen();
+}
 
 /****************************************************************************
   Stub for editor function
