@@ -1652,17 +1652,19 @@ struct terrain *help_widget::terrain_max_values()
     attack_strength, bombard_rate, build_cost, city_size, convert_time,
     defense_strength, firepower, fuel, happy_cost, hp, move_rate, pop_cost,
     upkeep, vision_radius_sq
-  Other fiels in returned value are undefined. Especially, all pointers are
+  Other fields in returned value are undefined. Especially, all pointers are
   invalid except uclass.
 **************************************************************************/
 struct unit_type *help_widget::uclass_max_values(struct unit_class *uclass)
 {
   struct unit_type *max = new struct unit_type;
+
   max->uclass = uclass;
   max->attack_strength = 0;
   max->bombard_rate = 0;
   max->build_cost = 0;
   max->city_size = 0;
+  max->convert_time = 0;
   max->defense_strength = 0;
   max->firepower = 0;
   max->fuel = 0;
@@ -1677,10 +1679,13 @@ struct unit_type *help_widget::uclass_max_values(struct unit_class *uclass)
   max->upkeep[O_SHIELD] = 0;
   max->upkeep[O_TRADE] = 0;
   max->vision_radius_sq = 0;
+
   unit_type_iterate(utype) {
     if (utype->uclass == uclass) {
-#define SET_MAX(v) \
+
+#define SET_MAX(v)                                      \
       max->v = max->v > utype->v ? max->v : utype->v
+
       SET_MAX(attack_strength);
       SET_MAX(bombard_rate);
       SET_MAX(build_cost);
@@ -1700,8 +1705,11 @@ struct unit_type *help_widget::uclass_max_values(struct unit_class *uclass)
       SET_MAX(upkeep[O_SHIELD]);
       SET_MAX(upkeep[O_TRADE]);
       SET_MAX(vision_radius_sq);
+
 #undef SET_MAX
+
     }
   } unit_type_iterate_end
+
   return max;
 }
