@@ -426,13 +426,12 @@ void units_reports::update_units(bool show)
   int output;
   int total_len = 0;
   struct urd_info *info;
-  struct urd_info unit_array[utype_count()];
+  struct urd_info *unit_array = (struct urd_info *)fc_calloc(sizeof(struct urd_info), utype_count());
   struct urd_info unit_totals;
   Unit_type_id utype_id;
   unittype_item *ui = nullptr;
 
   clear_layout();
-  memset(unit_array, '\0', sizeof(unit_array));
   memset(&unit_totals, '\0', sizeof(unit_totals));
   /* Count units. */
   players_iterate(pplayer) {
@@ -484,6 +483,8 @@ void units_reports::update_units(bool show)
     add_item(ui);
   } unit_type_iterate_end;
 
+  free(unit_array);
+
   setUpdatesEnabled(false);
   hide();
   i = unittype_list.count();
