@@ -99,7 +99,6 @@ Uint32 widget_info_counter = 0;
 int MOVE_STEP_X = DEFAULT_MOVE_STEP;
 int MOVE_STEP_Y = DEFAULT_MOVE_STEP;
 extern bool draw_goto_patrol_lines;
-SDL_Event *flush_event = NULL;
 bool is_unit_move_blocked;
 bool LSHIFT;
 bool RSHIFT;
@@ -114,6 +113,8 @@ int *client_font_sizes[FONT_COUNT] = {
   &city_productions_font_size  /* FONT_REQTREE_TEXT; not used yet */
 };
 
+static unsigned font_size_parameter = 0;
+
 /* ================================ Private ============================ */
 static int net_socket = -1;
 static bool autoconnect = FALSE;
@@ -123,13 +124,20 @@ static enum direction8 scroll_dir;
 static struct finger_behavior finger_behavior;
 static struct mouse_button_behavior button_behavior;
 
+static SDL_Event __Net_User_Event;
+static SDL_Event __Anim_User_Event;
+static SDL_Event __Info_User_Event;
+static SDL_Event __Flush_User_Event;
+static SDL_Event __pMap_Scroll_User_Event;
+
 static SDL_Event *pNet_User_Event = NULL;
 static SDL_Event *pAnim_User_Event = NULL;
 static SDL_Event *pInfo_User_Event = NULL;
+static SDL_Event *flush_user_event = NULL;
 static SDL_Event *pMap_Scroll_User_Event = NULL;
 
 static void print_usage(void);
-static void parse_options(int argc, char **argv);
+static bool parse_options(int argc, char **argv);
 static int check_scroll_area(int x, int y);
 
 int user_event_type;
@@ -167,6 +175,8 @@ static void print_usage(void)
   /* Add client-specific usage information here */
   fc_fprintf(stderr,
              _("  -f,  --fullscreen\tStart Client in Fullscreen mode\n"));
+  fc_fprintf(stderr,
+             _("  -F,  --Font SIZE\tUse SIZE as the base font size\n"));
   fc_fprintf(stderr, _("  -s,  --swrenderer\tUse SW renderer\n"));
   fc_fprintf(stderr, _("  -t,  --theme THEME\tUse GUI theme THEME\n"));
 
@@ -177,7 +187,7 @@ static void print_usage(void)
 /**************************************************************************
   Search for gui-specific command-line options.
 **************************************************************************/
-static void parse_options(int argc, char **argv)
+static bool parse_options(int argc, char **argv)
 {
   int i = 1;
   char *option = NULL;
@@ -185,11 +195,18 @@ static void parse_options(int argc, char **argv)
   while (i < argc) {
     if (is_option("--help", argv[i])) {
       print_usage();
-      exit(EXIT_SUCCESS);
+
+      return FALSE;
     } else if (is_option("--fullscreen", argv[i])) {
       gui_options.gui_sdl2_fullscreen = TRUE;
     } else if (is_option("--swrenderer", argv[i])) {
       SDL_Client_Flags |= CF_SWRENDERER;
+    } else if ((option = get_option_malloc("--Font", argv, &i, argc, FALSE))) {
+      if (!str_to_uint(option, &font_size_parameter)) {
+        fc_fprintf(stderr, _("Invalid font size %s"), option);
+        exit(EXIT_FAILURE);
+      }
+      free(option);
     } else if ((option = get_option_malloc("--theme", argv, &i, argc, FALSE))) {
       sz_strlcpy(gui_options.gui_sdl2_default_theme_name, option);
       free(option);
@@ -200,6 +217,8 @@ static void parse_options(int argc, char **argv)
 
     i++;
   }
+
+  return TRUE;
 }
 
 /**************************************************************************
@@ -592,7 +611,7 @@ Uint16 gui_event_loop(void *pData,
   t_last_map_scrolling = t_last_unit_anim = real_timer_next_call = SDL_GetTicks();
   while (ID == ID_ERROR) {
     /* ========================================= */
-    /* net check with 10ms delay event loop */
+    /* Net check with 10ms delay event loop */
     if (net_socket >= 0) {
       FD_ZERO(&civfdset);
 
@@ -617,7 +636,7 @@ Uint16 gui_event_loop(void *pData,
           }
         }
       }
-    } else { /* if connection is not establish */
+    } else { /* If connection is not establish */
       SDL_Delay(10);
     }
     /* ========================================= */
@@ -967,103 +986,131 @@ static void migrate_options_from_sdl(void)
 **************************************************************************/
 int ui_main(int argc, char *argv[])
 {
-  SDL_Event __Net_User_Event;
-  SDL_Event __Anim_User_Event;
-  SDL_Event __Info_User_Event;
-  SDL_Event __Flush_User_Event;
-  SDL_Event __pMap_Scroll_User_Event;
   Uint32 flags = 0;
 
-  parse_options(argc, argv);
+  if (parse_options(argc, argv)) {
+    if (!gui_options.gui_sdl2_migrated_from_sdl) {
+      migrate_options_from_sdl();
+    }
 
-  if (!gui_options.gui_sdl2_migrated_from_sdl) {
-    migrate_options_from_sdl();
+    if (gui_options.gui_sdl2_fullscreen) {
+      flags |= SDL_WINDOW_FULLSCREEN;
+    } else {
+      flags &= ~SDL_WINDOW_FULLSCREEN;
+    }
+    log_normal(_("Using Video Output: %s"), SDL_GetCurrentVideoDriver());
+    if (!set_video_mode(gui_options.gui_sdl2_screen.width,
+                        gui_options.gui_sdl2_screen.height,
+                        flags)) {
+      return EXIT_FAILURE;
+    }
+
+    user_event_type = SDL_RegisterEvents(1);
+
+    SDL_zero(__Net_User_Event);
+    __Net_User_Event.type = user_event_type;
+    __Net_User_Event.user.code = NET;
+    __Net_User_Event.user.data1 = NULL;
+    __Net_User_Event.user.data2 = NULL;
+    pNet_User_Event = &__Net_User_Event;
+
+    SDL_zero(__Anim_User_Event);
+    __Anim_User_Event.type = user_event_type;
+    __Anim_User_Event.user.code = EVENT_ERROR;
+    __Anim_User_Event.user.data1 = NULL;
+    __Anim_User_Event.user.data2 = NULL;
+    pAnim_User_Event = &__Anim_User_Event;
+
+    SDL_zero(__Info_User_Event);
+    __Info_User_Event.type = user_event_type;
+    __Info_User_Event.user.code = SHOW_WIDGET_INFO_LABEL;
+    __Info_User_Event.user.data1 = NULL;
+    __Info_User_Event.user.data2 = NULL;
+    pInfo_User_Event = &__Info_User_Event;
+
+    SDL_zero(__Flush_User_Event);
+    __Flush_User_Event.type = user_event_type;
+    __Flush_User_Event.user.code = FLUSH;
+    __Flush_User_Event.user.data1 = NULL;
+    __Flush_User_Event.user.data2 = NULL;
+    flush_user_event = &__Flush_User_Event;
+
+    SDL_zero(__pMap_Scroll_User_Event);
+    __pMap_Scroll_User_Event.type = user_event_type;
+    __pMap_Scroll_User_Event.user.code = MAP_SCROLL;
+    __pMap_Scroll_User_Event.user.data1 = NULL;
+    __pMap_Scroll_User_Event.user.data2 = NULL;
+    pMap_Scroll_User_Event = &__pMap_Scroll_User_Event;
+
+    is_unit_move_blocked = FALSE;
+
+    SDL_Client_Flags |= (CF_DRAW_PLAYERS_NEUTRAL_STATUS
+                         |CF_DRAW_PLAYERS_WAR_STATUS
+                         |CF_DRAW_PLAYERS_CEASEFIRE_STATUS
+                         |CF_DRAW_PLAYERS_PEACE_STATUS
+                         |CF_DRAW_PLAYERS_ALLIANCE_STATUS);
+
+    tileset_init(tileset);
+    tileset_load_tiles(tileset);
+    tileset_use_preferred_theme(tileset);
+
+    load_cursors();
+
+    callbacks = callback_list_new();
+
+    diplomacy_dialog_init();
+    intel_dialog_init();
+
+    clear_double_messages_call();
+
+    setup_auxiliary_tech_icons();
+
+    /* This need correct Main.screen size */
+    init_mapcanvas_and_overview();
+
+    set_client_state(C_S_DISCONNECTED);
+
+    /* Main game loop */
+    gui_event_loop(NULL, NULL, main_key_down_handler, main_key_up_handler, NULL,
+                   main_finger_down_handler, main_finger_up_handler, NULL,
+                   main_mouse_button_down_handler, main_mouse_button_up_handler,
+                   main_mouse_motion_handler);
+    start_quitting();
+
+#if defined UNDER_CE && defined SMALL_SCREEN
+    /* Change back to window mode to restore the title bar */
+    set_video_mode(320, 240, SDL_SWSURFACE | SDL_ANYFORMAT);
+#endif
+
+    city_map_canvas_free();
+
+    free_mapcanvas_and_overview();
+
+    free_auxiliary_tech_icons();
+    free_intro_radar_sprites();
+
+    diplomacy_dialog_done();
+    intel_dialog_done();
+
+    callback_list_destroy(callbacks);
+    callbacks = NULL;
+
+    unload_cursors();
+
+    free(button_behavior.event);
+    button_behavior.event = NULL;
+
+    meswin_dialog_popdown();
+
+    del_main_list();
+
+    free_font_system();
+    theme_free(theme);
+    theme = NULL;
+
+    quit_sdl();
   }
 
-  if (gui_options.gui_sdl2_fullscreen) {
-    flags |= SDL_WINDOW_FULLSCREEN;
-  } else {
-    flags &= ~SDL_WINDOW_FULLSCREEN;
-  }
-  log_normal(_("Using Video Output: %s"), SDL_GetCurrentVideoDriver());
-  if (!set_video_mode(gui_options.gui_sdl2_screen.width,
-                      gui_options.gui_sdl2_screen.height,
-                      flags)) {
-    return EXIT_FAILURE;
-  }
-
-  user_event_type = SDL_RegisterEvents(1);
-
-  SDL_zero(__Net_User_Event);
-  __Net_User_Event.type = user_event_type;
-  __Net_User_Event.user.code = NET;
-  __Net_User_Event.user.data1 = NULL;
-  __Net_User_Event.user.data2 = NULL;
-  pNet_User_Event = &__Net_User_Event;
-
-  SDL_zero(__Anim_User_Event);
-  __Anim_User_Event.type = user_event_type;
-  __Anim_User_Event.user.code = EVENT_ERROR;
-  __Anim_User_Event.user.data1 = NULL;
-  __Anim_User_Event.user.data2 = NULL;
-  pAnim_User_Event = &__Anim_User_Event;
-
-  SDL_zero(__Info_User_Event);
-  __Info_User_Event.type = user_event_type;
-  __Info_User_Event.user.code = SHOW_WIDGET_INFO_LABEL;
-  __Info_User_Event.user.data1 = NULL;
-  __Info_User_Event.user.data2 = NULL;
-  pInfo_User_Event = &__Info_User_Event;
-
-  SDL_zero(__Flush_User_Event);
-  __Flush_User_Event.type = user_event_type;
-  __Flush_User_Event.user.code = FLUSH;
-  __Flush_User_Event.user.data1 = NULL;
-  __Flush_User_Event.user.data2 = NULL;
-  flush_event = &__Flush_User_Event;
-
-  SDL_zero(__pMap_Scroll_User_Event);
-  __pMap_Scroll_User_Event.type = user_event_type;
-  __pMap_Scroll_User_Event.user.code = MAP_SCROLL;
-  __pMap_Scroll_User_Event.user.data1 = NULL;
-  __pMap_Scroll_User_Event.user.data2 = NULL;
-  pMap_Scroll_User_Event = &__pMap_Scroll_User_Event;
-
-  is_unit_move_blocked = FALSE;
-
-  SDL_Client_Flags |= (CF_DRAW_PLAYERS_NEUTRAL_STATUS
-                       |CF_DRAW_PLAYERS_WAR_STATUS
-                       |CF_DRAW_PLAYERS_CEASEFIRE_STATUS
-                       |CF_DRAW_PLAYERS_PEACE_STATUS
-                       |CF_DRAW_PLAYERS_ALLIANCE_STATUS);
-
-  tileset_init(tileset);
-  tileset_load_tiles(tileset);
-  tileset_use_preferred_theme(tileset);
-
-  load_cursors();
-
-  callbacks = callback_list_new();
-
-  diplomacy_dialog_init();
-  intel_dialog_init();
-
-  clear_double_messages_call();
-
-  setup_auxiliary_tech_icons();
-
-  /* this need correct Main.screen size */
-  init_mapcanvas_and_overview();
-
-  set_client_state(C_S_DISCONNECTED);
-
-  /* Main game loop */
-  gui_event_loop(NULL, NULL, main_key_down_handler, main_key_up_handler, NULL,
-                 main_finger_down_handler, main_finger_up_handler, NULL,
-                 main_mouse_button_down_handler, main_mouse_button_up_handler,
-                 main_mouse_motion_handler);
-  start_quitting();
-
   return EXIT_SUCCESS;
 }
 
@@ -1072,38 +1119,6 @@ int ui_main(int argc, char *argv[])
 **************************************************************************/
 void ui_exit(void)
 {
-
-#if defined UNDER_CE && defined SMALL_SCREEN
-  /* change back to window mode to restore the title bar */
-  set_video_mode(320, 240, SDL_SWSURFACE | SDL_ANYFORMAT);
-#endif
-
-  city_map_canvas_free();
-
-  free_mapcanvas_and_overview();
-
-  free_auxiliary_tech_icons();
-  free_intro_radar_sprites();
-
-  diplomacy_dialog_done();
-  intel_dialog_done();
-
-  callback_list_destroy(callbacks);
-  callbacks = NULL;
-
-  unload_cursors();
-
-  FC_FREE(button_behavior.event);
-
-  meswin_dialog_popdown();
-
-  del_main_list();
-
-  free_font_system();
-  theme_free(theme);
-  theme = NULL;
-
-  quit_sdl();
 }
 
 /**************************************************************************
@@ -1241,6 +1256,15 @@ void gui_update_font(const char *font_name, const char *font_value)
 #undef CHECK_FONT
 }
 
+/**************************************************************************
+  Return default font size, from any source.
+**************************************************************************/
+unsigned default_font_size(struct theme *act_theme)
+{
+  return font_size_parameter > 0 ? font_size_parameter :
+    theme_default_font_size(act_theme);
+}
+
 /**************************************************************************
   Update font sizes based on theme.
 **************************************************************************/
@@ -1257,3 +1281,11 @@ void insert_client_build_info(char *outbuf, size_t outlen)
 {
   /* PORTME */
 }
+
+/**************************************************************************
+  Queue a flush event to be handled later by SDL.
+**************************************************************************/
+bool flush_event(void)
+{
+  return SDL_PushEvent(flush_user_event) >= 0;
+}
