@@ -371,10 +371,12 @@ void popup_impr_info(Impr_type_id impr)
   pImpr_type = improvement_by_number(impr);
 
   pSurf = get_building_surface(pImpr_type);
-  pImprNameLabel = create_iconlabel_from_chars(
-                     ResizeSurfaceBox(pSurf, adj_size(64), adj_size(48), 1, TRUE, TRUE),
-                     pWindow->dst, city_improvement_name_translation(NULL, pImpr_type),
-                     adj_font(24), WF_FREE_THEME);
+  pImprNameLabel
+    = create_iconlabel_from_chars_fonto(ResizeSurfaceBox(pSurf, adj_size(64), adj_size(48),
+                                                         1, TRUE, TRUE),
+                                        pWindow->dst,
+                                        city_improvement_name_translation(NULL, pImpr_type),
+                                        FONTO_MAX, WF_FREE_THEME);
 
   pImprNameLabel->ID = ID_LABEL;
   DownAdd(pImprNameLabel, pDock);
@@ -794,10 +796,11 @@ void popup_unit_info(Unit_type_id type_id)
   }
 
   pUnitType = utype_by_number(type_id);
-  pUnitNameLabel= create_iconlabel_from_chars(
-                adj_surf(get_unittype_surface(pUnitType, direction8_invalid())),
-                pWindow->dst, utype_name_translation(pUnitType),
-                adj_font(24), WF_FREE_THEME);
+  pUnitNameLabel
+    = create_iconlabel_from_chars_fonto(adj_surf(get_unittype_surface(pUnitType,
+                                                                      direction8_invalid())),
+                                        pWindow->dst, utype_name_translation(pUnitType),
+                                        FONTO_MAX, WF_FREE_THEME);
 
   pUnitNameLabel->ID = ID_LABEL;
   DownAdd(pUnitNameLabel, pDock);
@@ -1067,7 +1070,7 @@ static void redraw_tech_info_dlg(void)
                get_theme_color(COLOR_THEME_HELPDLG_FRAME));
 
   /* -------------------------- */
-  pstr = create_utf8_from_char(_("Allows"), adj_font(14));
+  pstr = create_utf8_from_char_fonto(_("Allows"), FONTO_HEADING);
   pstr->style |= TTF_STYLE_BOLD;
 
   pText0 = create_text_surf_from_utf8(pstr);
@@ -1142,11 +1145,10 @@ static struct widget *create_tech_info(Tech_type_id tech, int width,
   pDock = pWidget;
 
   /* Tech name (heading) */
-  pWidget = create_iconlabel_from_chars(get_tech_icon(tech),
-                    pWindow->dst,
-                    advance_name_translation(advance_by_number(tech)),
-                    adj_font(24),
-                    WF_FREE_THEME);
+  pWidget = create_iconlabel_from_chars_fonto(get_tech_icon(tech),
+                                              pWindow->dst,
+                                              advance_name_translation(advance_by_number(tech)),
+                                              FONTO_MAX, WF_FREE_THEME);
 
   pWidget->ID = ID_LABEL;
   DownAdd(pWidget, pDock);
@@ -1220,10 +1222,11 @@ static struct widget *create_tech_info(Tech_type_id tech, int width,
       if (VUT_ADVANCE == preq->source.kind
           && advance_number(preq->source.value.advance) == tech) {
 
-        pWidget = create_iconlabel_from_chars(adj_surf(get_government_surface(gov)),
+        pWidget
+          = create_iconlabel_from_chars_fonto(adj_surf(get_government_surface(gov)),
                 pWindow->dst,
                 government_name_translation(gov),
-                adj_font(14),
+                FONTO_HEADING,
                 WF_RESTORE_BACKGROUND | WF_SELECT_WITHOUT_BAR | WF_FREE_THEME);
         set_wstate(pWidget, FC_WS_NORMAL);
         pWidget->action = change_gov_callback;
@@ -1246,11 +1249,12 @@ static struct widget *create_tech_info(Tech_type_id tech, int width,
         if (VUT_ADVANCE == preq->source.kind
             && advance_number(preq->source.value.advance) == tech) {
           pSurf = get_building_surface(pimprove);
-          pWidget = create_iconlabel_from_chars(
+          pWidget
+            = create_iconlabel_from_chars_fonto(
                   ResizeSurfaceBox(pSurf, adj_size(48), adj_size(48), 1, TRUE, TRUE),
                   pWindow->dst,
                   improvement_name_translation(pimprove),
-                  adj_font(14),
+                  FONTO_HEADING,
                   WF_RESTORE_BACKGROUND | WF_SELECT_WITHOUT_BAR);
           set_wstate(pWidget, FC_WS_NORMAL);
           if (is_wonder(pimprove)) {
@@ -1270,13 +1274,11 @@ static struct widget *create_tech_info(Tech_type_id tech, int width,
 
   unit_count = 0;
   unit_type_iterate(un) {
-    struct unit_type *pUnitType = un;
-
-    if (advance_number(pUnitType->require_advance) == tech) {
-      pWidget = create_iconlabel_from_chars(
+    if (advance_number(un->require_advance) == tech) {
+      pWidget = create_iconlabel_from_chars_fonto(
                                    ResizeSurfaceBox(get_unittype_surface(un, direction8_invalid()),
                                    adj_size(48), adj_size(48), 1, TRUE, TRUE),
-                  pWindow->dst, utype_name_translation(pUnitType), adj_font(14),
+                  pWindow->dst, utype_name_translation(un), FONTO_HEADING,
                   (WF_FREE_THEME | WF_RESTORE_BACKGROUND | WF_SELECT_WITHOUT_BAR));
       set_wstate(pWidget, FC_WS_NORMAL);
       pWidget->action = change_unit_callback;
@@ -1664,7 +1666,7 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
                                        struct widget *pWindow,
                                        struct TECHS_BUTTONS *pStore)
 {
-  int i, w, h, req_count , targets_count, sub_req_count, sub_targets_count;
+  int i, w, h, req_count, targets_count, sub_req_count, sub_targets_count;
   struct widget *pWidget;
   struct widget *pTech;
   utf8_str *pstr;
@@ -1686,7 +1688,7 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
   pTech = pWidget;
   pDock = pWidget;
 
-  req_count  = 0;
+  req_count = 0;
   for (i = AR_ONE; i <= AR_TWO; i++) {
     Tech_type_id ar = advance_required(tech, i);
     struct advance *vap = valid_advance_by_number(ar);
@@ -1701,16 +1703,13 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
       pWidget->ID = MAX_ID - ar;
       DownAdd(pWidget, pDock);
       pDock = pWidget;
-      pStore->pRequirementButton[i] = pWidget;
-      req_count++;
-    } else {
-      pStore->pRequirementButton[i] = NULL;
+      pStore->pRequirementButton[req_count++] = pWidget;
     }
   }
 
   sub_req_count = 0;
 
-  if (pStore->show_full_tree && req_count) {
+  if (pStore->show_full_tree && req_count > 0) {
     int j, sub_tech;
 
     for (j = 0; j < req_count; j++) {
@@ -1762,7 +1761,7 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
   }
 
   sub_targets_count = 0;
-  if (targets_count) {
+  if (targets_count > 0) {
     int sub_tech;
 
     for (i = 0; i < targets_count; i++) {
@@ -1796,13 +1795,15 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
   FREEUTF8STR(pstr);
 
   /* ------------------------------------------ */
-  if (sub_req_count) {
+  if (sub_req_count > 0) {
     w = (adj_size(20) + pStore->pSub_Req[0]->size.w) * 2;
     w += (pWindow->size.w - (20 + pStore->pSub_Req[0]->size.w + w + pTech->size.w)) / 2;
   } else {
-    if (req_count) {
-      w = (pWindow->area.x + 1 + width + pStore->pRequirementButton[0]->size.w * 2 + adj_size(20));
-      w += (pWindow->size.w - ((adj_size(20) + pStore->pRequirementButton[0]->size.w) + w + pTech->size.w)) / 2;
+    if (req_count > 0) {
+      w = (pWindow->area.x + 1
+           + width + pStore->pRequirementButton[0]->size.w * 2 + adj_size(20));
+      w += (pWindow->size.w - ((adj_size(20) + pStore->pRequirementButton[0]->size.w)
+                               + w + pTech->size.w)) / 2;
     } else {
       w = (pWindow->size.w - pTech->size.w) / 2;
     }
@@ -1811,29 +1812,31 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
   pTech->size.x = pWindow->size.x + w;
   pTech->size.y = pWindow->area.y + (pWindow->area.h - pTech->size.h) / 2;
 
-  if (req_count) {
+  if (req_count > 0) {
     h = (req_count == 1 ? pStore->pRequirementButton[0]->size.h :
         req_count * (pStore->pRequirementButton[0]->size.h + adj_size(80)) - adj_size(80));
     h = pTech->size.y + (pTech->size.h - h) / 2;
     for (i = 0; i < req_count; i++) {
-      pStore->pRequirementButton[i]->size.x = pTech->size.x - adj_size(20) - pStore->pRequirementButton[i]->size.w;
+      pStore->pRequirementButton[i]->size.x
+        = pTech->size.x - adj_size(20) - pStore->pRequirementButton[i]->size.w;
       pStore->pRequirementButton[i]->size.y = h;
       h += (pStore->pRequirementButton[i]->size.h + adj_size(80));
     }
   }
 
-  if (sub_req_count) {
+  if (sub_req_count > 0) {
     h = (sub_req_count == 1 ? pStore->pSub_Req[0]->size.h :
      sub_req_count * (pStore->pSub_Req[0]->size.h + adj_size(20)) - adj_size(20));
     h = pTech->size.y + (pTech->size.h - h) / 2;
     for (i = 0; i < sub_req_count; i++) {
-      pStore->pSub_Req[i]->size.x = pTech->size.x - (adj_size(20) + pStore->pSub_Req[i]->size.w) * 2;
+      pStore->pSub_Req[i]->size.x
+        = pTech->size.x - (adj_size(20) + pStore->pSub_Req[i]->size.w) * 2;
       pStore->pSub_Req[i]->size.y = h;
       h += (pStore->pSub_Req[i]->size.h + adj_size(20));
     }
   }
 
-  if (targets_count) {
+  if (targets_count > 0) {
     h = (targets_count == 1 ? pStore->pTargets[0]->size.h :
      targets_count * (pStore->pTargets[0]->size.h + adj_size(20)) - adj_size(20));
     h = pTech->size.y + (pTech->size.h - h) / 2;
@@ -1844,22 +1847,30 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
     }
   }
 
-  if (sub_targets_count) {
+  if (sub_targets_count > 0) {
     if (sub_targets_count < 3) {
-      pStore->pSub_Targets[0]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[0]->size.w;
-      pStore->pSub_Targets[0]->size.y = pTech->size.y - pStore->pSub_Targets[0]->size.h - adj_size(10);
+      pStore->pSub_Targets[0]->size.x
+        = pTech->size.x + pTech->size.w - pStore->pSub_Targets[0]->size.w;
+      pStore->pSub_Targets[0]->size.y
+        = pTech->size.y - pStore->pSub_Targets[0]->size.h - adj_size(10);
       if (pStore->pSub_Targets[1]) {
-        pStore->pSub_Targets[1]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[1]->size.w;
-        pStore->pSub_Targets[1]->size.y = pTech->size.y + pTech->size.h + adj_size(10);
+        pStore->pSub_Targets[1]->size.x
+          = pTech->size.x + pTech->size.w - pStore->pSub_Targets[1]->size.w;
+        pStore->pSub_Targets[1]->size.y
+          = pTech->size.y + pTech->size.h + adj_size(10);
       }
     } else {
       if (sub_targets_count < 5) {
         for (i = 0; i < MIN(sub_targets_count, 4); i++) {
-          pStore->pSub_Targets[i]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
+          pStore->pSub_Targets[i]->size.x
+            = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
           if (i < 2) {
-            pStore->pSub_Targets[i]->size.y = pTech->size.y - (pStore->pSub_Targets[i]->size.h + adj_size(5)) * ( 2 - i );
+            pStore->pSub_Targets[i]->size.y
+              = pTech->size.y - (pStore->pSub_Targets[i]->size.h + adj_size(5)) * (2 - i);
           } else {
-            pStore->pSub_Targets[i]->size.y = pTech->size.y + pTech->size.h + adj_size(5)  + (pStore->pSub_Targets[i]->size.h + adj_size(5)) * ( i - 2 );
+            pStore->pSub_Targets[i]->size.y
+              = pTech->size.y + pTech->size.h + adj_size(5)
+                + (pStore->pSub_Targets[i]->size.h + adj_size(5)) * (i - 2);
           }
         }
       } else {
@@ -1867,28 +1878,39 @@ static struct widget *create_tech_tree(Tech_type_id tech, int width,
         for (i = 0; i < MIN(sub_targets_count, 6); i++) {
           switch(i) {
           case 0:
-            pStore->pSub_Targets[i]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
+            pStore->pSub_Targets[i]->size.x
+              = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
             pStore->pSub_Targets[i]->size.y = pTech->size.y - h * 2;
             break;
           case 1:
-            pStore->pSub_Targets[i]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w * 2 - adj_size(10);
+            pStore->pSub_Targets[i]->size.x
+              = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w * 2
+                - adj_size(10);
             pStore->pSub_Targets[i]->size.y = pTech->size.y - h - h / 2;
             break;
           case 2:
-            pStore->pSub_Targets[i]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
+            pStore->pSub_Targets[i]->size.x
+              = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
             pStore->pSub_Targets[i]->size.y = pTech->size.y - h;
             break;
           case 3:
-            pStore->pSub_Targets[i]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
-            pStore->pSub_Targets[i]->size.y = pTech->size.y + pTech->size.h + adj_size(6);
+            pStore->pSub_Targets[i]->size.x
+              = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
+            pStore->pSub_Targets[i]->size.y
+              = pTech->size.y + pTech->size.h + adj_size(6);
             break;
           case 4:
-            pStore->pSub_Targets[i]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
-            pStore->pSub_Targets[i]->size.y = pTech->size.y + pTech->size.h + adj_size(6) + h;
+            pStore->pSub_Targets[i]->size.x
+              = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w;
+            pStore->pSub_Targets[i]->size.y
+              = pTech->size.y + pTech->size.h + adj_size(6) + h;
             break;
           default:
-            pStore->pSub_Targets[i]->size.x = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w * 2 - adj_size(10);
-            pStore->pSub_Targets[i]->size.y = pTech->size.y + pTech->size.h + adj_size(6) + h / 2 ;
+            pStore->pSub_Targets[i]->size.x
+              = pTech->size.x + pTech->size.w - pStore->pSub_Targets[i]->size.w * 2
+                - adj_size(10);
+            pStore->pSub_Targets[i]->size.y
+              = pTech->size.y + pTech->size.h + adj_size(6) + h / 2 ;
             break;
           }
         }
