@@ -176,12 +176,12 @@ static struct intel_dialog *create_intel_dialog(struct player *pPlayer)
 **************************************************************************/
 void popup_intel_dialog(struct player *p)
 {
-  struct intel_dialog *pdialog;
+  struct intel_dialog *pdialog = get_intel_dialog(p);
 
-  if (!(pdialog = get_intel_dialog(p))) {
-    pdialog = create_intel_dialog(p);
+  if (pdialog == NULL) {
+    create_intel_dialog(p);
   } else {
-    /* bring existing dialog to front */
+    /* Bring existing dialog to front */
     select_window_group_dialog(pdialog->pdialog->pBeginWidgetList,
                                pdialog->pdialog->pEndWidgetList);
   }
@@ -307,7 +307,7 @@ void update_intel_dialog(struct player *p)
                 _("Intelligence Information for the %s Empire"),
                 nation_adjective_for_player(p));
 
-    pstr = create_utf8_from_char(cBuf, adj_font(14));
+    pstr = create_utf8_from_char_fonto(cBuf, FONTO_HEADING);
     pstr->style |= TTF_STYLE_BOLD;
     pstr->bgcol = (SDL_Color) {0, 0, 0, 0};
 
