@@ -382,8 +382,8 @@ static void calculate_diagram_layout(struct reqtree *tree)
 
 
 /*************************************************************************
-  Create a "dummy" tech tree from current ruleset.  This tree is then
-  fleshed out further (see create_reqtree). This tree doesn't include
+  Create a "dummy" tech tree from current ruleset. This tree is then
+  fleshed out further (see create_reqtree() ). This tree doesn't include
   dummy edges. Layering and ordering isn't done also.
 
   If pplayer is given, add only techs reachable by that player to tree.
@@ -394,10 +394,11 @@ static struct reqtree *create_dummy_reqtree(struct player *pplayer,
   const struct research *presearch = research_get(pplayer);
   struct reqtree *tree = fc_malloc(sizeof(*tree));
   int j;
-  struct tree_node *nodes[advance_count()];
+  Tech_type_id ac = advance_count();
+  struct tree_node *nodes[ac];
 
   nodes[A_NONE] = NULL;
-  advance_index_iterate(A_FIRST, tech) {
+  advance_index_iterate_max(A_FIRST, tech, ac) {
     if (!valid_advance_by_number(tech)) {
       nodes[tech] = NULL;
       continue;
@@ -405,16 +406,16 @@ static struct reqtree *create_dummy_reqtree(struct player *pplayer,
     if (pplayer && !show_all
         && !research_invention_reachable(presearch, tech)) {
       /* Reqtree requested for particular player and this tech is
-       * unreachable to him/her. */
+       * unreachable to them. */
       nodes[tech] = NULL;
       continue;
     }
     nodes[tech] = new_tree_node();
     nodes[tech]->is_dummy = FALSE;
     nodes[tech]->tech = tech;
-  } advance_index_iterate_end;
+  } advance_index_iterate_max_end;
 
-  advance_index_iterate(A_FIRST, tech) {
+  advance_index_iterate_max(A_FIRST, tech, ac) {
     struct advance *padvance = valid_advance_by_number(tech);
     Tech_type_id tech_one, tech_two;
 
@@ -435,9 +436,9 @@ static struct reqtree *create_dummy_reqtree(struct player *pplayer,
       continue;
     }
 
-    /* Formerly, we used to remove the redundant requirement nodes (the
-     * technologies already included in the requirements of the other
-     * requirement).  However, it doesn't look like a good idea, because
+    /* Formerly, we used to remove the redundant requirement nodes
+     * (the technologies already included in the requirements of the other
+     * requirement). However, it doesn't look like a good idea, because
      * a player can steal any technology independently of the technology
      * tree. */
     if (A_NONE != tech_one && A_LAST != tech_two) {
@@ -446,18 +447,18 @@ static struct reqtree *create_dummy_reqtree(struct player *pplayer,
         add_requirement(nodes[tech], nodes[tech_two]);
       }
     }
-  } advance_index_iterate_end;
+  } advance_index_iterate_max_end;
 
-  /* Copy nodes from local array to dynamically allocated one. 
+  /* Copy nodes from local array to dynamically allocated one.
    * Skip non-existing entries */
-  tree->nodes = fc_calloc(advance_count(), sizeof(*tree->nodes));
+  tree->nodes = fc_calloc(ac, sizeof(*tree->nodes));
   j = 0;
-  advance_index_iterate(A_FIRST, tech) {
+  advance_index_iterate_max(A_FIRST, tech, ac) {
     if (nodes[tech]) {
       fc_assert_action(valid_advance_by_number(nodes[tech]->tech), continue);
       tree->nodes[j++] = nodes[tech];
     }
-  } advance_index_iterate_end;
+  } advance_index_iterate_max_end;
   tree->num_nodes = j;
   tree->layers = NULL;
 
@@ -639,7 +640,7 @@ static void set_layers(struct reqtree *tree)
   int i;
   int num_layers = 0;
   
-  /* count total number of layers */
+  /* Count total number of layers */
   for (i = 0; i < tree->num_nodes; i++) {
     num_layers = MAX(num_layers, tree->nodes[i]->layer);
   }
@@ -661,8 +662,8 @@ static void set_layers(struct reqtree *tree)
     }
 
     for (i = 0; i < num_layers; i++) {
-      tree->layers[i] =
-	  fc_malloc(sizeof(*tree->layers[i]) * tree->layer_size[i]);
+      tree->layers[i]
+        = fc_malloc(sizeof(*tree->layers[i]) * tree->layer_size[i]);
     }
     for (i = 0; i < tree->num_nodes; i++) {
       struct tree_node *node = tree->nodes[i];
@@ -697,38 +698,40 @@ static int cmp_func(const void *_a, const void *_b)
 
 /*************************************************************************
   Simple heuristic: Sort nodes on the given layer by the average x-value
-  of its' parents.
+  of its parents.
 *************************************************************************/
 static void barycentric_sort(struct reqtree *tree, int layer)
 {
-  struct node_and_float T[tree->layer_size[layer]];
-  int i, j;
-  float v;
+  if (tree->layer_size[layer] > 0) {
+    struct node_and_float T[tree->layer_size[layer]];
+    int i, j;
+    float v;
 
-  for (i = 0; i < tree->layer_size[layer]; i++) {
-    struct tree_node *node = tree->layers[layer][i];
+    for (i = 0; i < tree->layer_size[layer]; i++) {
+      struct tree_node *node = tree->layers[layer][i];
 
-    T[i].node = node;
-    v = 0.0;
-    for (j = 0; j < node->nrequire; j++) {
-      v += node->require[j]->order;
+      T[i].node = node;
+      v = 0.0;
+      for (j = 0; j < node->nrequire; j++) {
+        v += node->require[j]->order;
+      }
+      if (node->nrequire > 0) {
+        v /= (float) node->nrequire;
+      }
+      T[i].value = v;
     }
-    if (node->nrequire > 0) {
-      v /= (float) node->nrequire;
-    }
-    T[i].value = v;
-  }
-  qsort(T, tree->layer_size[layer], sizeof(*T),
-	cmp_func);
+    qsort(T, tree->layer_size[layer], sizeof(*T),
+          cmp_func);
 
-  for (i = 0; i < tree->layer_size[layer]; i++) {
-    tree->layers[layer][i] = T[i].node;
-    T[i].node->order = i;
+    for (i = 0; i < tree->layer_size[layer]; i++) {
+      tree->layers[layer][i] = T[i].node;
+      T[i].node->order = i;
+    }
   }
 }
 
 /*************************************************************************
-  Calculate number of edge crossings between layer and layer+1
+  Calculate number of edge crossings between layer and layer + 1
 *************************************************************************/
 static int count_crossings(struct reqtree *tree, int layer)
 {
@@ -778,47 +781,48 @@ static void swap(struct reqtree *tree, int layer, int order1, int order2)
 *************************************************************************/
 static void improve(struct reqtree *tree)
 {
-  int crossings[tree->num_layers - 1];
+  int layers = tree->num_layers;
+  int crossings[layers - 1];
   int i, x1, x2, layer;
 
-  for (i = 0; i < tree->num_layers - 1; i++) {
+  for (i = 0; i < layers - 1; i++) {
     crossings[i] = count_crossings(tree, i);
   }
 
-  for (layer = 0; layer < tree->num_layers; layer++) {
+  for (layer = 0; layer < layers; layer++) {
     int layer_size = tree->layer_size[layer];
     int layer_sum = 0;
 
     if (layer > 0) {
       layer_sum += crossings[layer - 1];
     }
-    if (layer < tree->num_layers - 1) {
+    if (layer < layers - 1) {
       layer_sum += crossings[layer];
     }
 
     for (x1 = 0; x1 < layer_size; x1++) {
       for (x2 = x1 + 1; x2 < layer_size; x2++) {
-	int new_crossings = 0;
-	int new_crossings_before = 0;
+        int new_crossings = 0;
+        int new_crossings_before = 0;
 
-	swap(tree, layer, x1, x2);
-	if (layer > 0) {
-	  new_crossings_before += count_crossings(tree, layer - 1);
-	}
-	if (layer < tree->num_layers - 1) {
-	  new_crossings += count_crossings(tree, layer);
-	}
-	if (new_crossings + new_crossings_before > layer_sum) {
-	  swap(tree, layer, x1, x2);
-	} else {
-	  layer_sum = new_crossings + new_crossings_before;
-	  if (layer > 0) {
-	    crossings[layer - 1] = new_crossings_before;
-	  }
-	  if (layer < tree->num_layers - 1) {
-	    crossings[layer] = new_crossings;
-	  }
-	}
+        swap(tree, layer, x1, x2);
+        if (layer > 0) {
+          new_crossings_before += count_crossings(tree, layer - 1);
+        }
+        if (layer < layers - 1) {
+          new_crossings += count_crossings(tree, layer);
+        }
+        if (new_crossings + new_crossings_before > layer_sum) {
+          swap(tree, layer, x1, x2);
+        } else {
+          layer_sum = new_crossings + new_crossings_before;
+          if (layer > 0) {
+            crossings[layer - 1] = new_crossings_before;
+          }
+          if (layer < layers - 1) {
+            crossings[layer] = new_crossings;
+          }
+        }
       }
     }
   }
@@ -826,7 +830,7 @@ static void improve(struct reqtree *tree)
 
 /*************************************************************************
   Generate optimized tech_tree from current ruleset.
-  You should free it by destroy_reqtree.
+  You should free it by destroy_reqtree().
 
   If pplayer is not NULL, techs unreachable to that player are not shown.
 *************************************************************************/
@@ -840,14 +844,14 @@ struct reqtree *create_reqtree(struct player *pplayer, bool show_all)
   tree2 = add_dummy_nodes(tree1);
   destroy_reqtree(tree1);
   set_layers(tree2);
-  
+
   /* It's good heuristics for beginning */
   for (j = 0; j < 20; j++) {
     for (i = 0; i < tree2->num_layers; i++) {
       barycentric_sort(tree2, i);
     }
   }
-  
+
   /* Now burn some CPU */
   for (j = 0; j < 20; j++) {
     improve(tree2);
