@@ -40,6 +40,8 @@ const struct functions *fc_funcs = NULL;
    available via fc_funcs. */
 bool fc_funcs_defined = FALSE;
 
+bool am_i_server = FALSE;
+
 /**************************************************************************
   Return the function pointer. Only possible before interface_init() was
   called (fc_funcs_defined FALSE).
@@ -51,6 +53,22 @@ struct functions *fc_interface_funcs(void)
   return &fc_functions;
 }
 
+/**************************************************************************
+  Set program type to server.
+**************************************************************************/
+void i_am_server(void)
+{
+  am_i_server = TRUE;
+}
+
+/**************************************************************************
+  Set program type to client.
+**************************************************************************/
+void i_am_client(void)
+{
+  am_i_server = FALSE;
+}
+
 /**************************************************************************
   Initialize libfreeciv.
   With check_fc_interface, also tests and initialize the functions.
