@@ -504,7 +504,7 @@ static bool impr_allows_actions(const struct city *pcity,
           }
 
           if (utype_player_already_has_this(city_owner(pcity), ut)) {
-            /* The player has a unit that may use the buidling */
+            /* The player has a unit that may use the building */
             return TRUE;
           }
 
@@ -833,7 +833,14 @@ bool wonder_is_built(const struct player *pplayer,
 struct city *city_from_wonder(const struct player *pplayer,
                               const struct impr_type *pimprove)
 {
-  int city_id = pplayer->wonders[improvement_index(pimprove)];
+  int idx = improvement_index(pimprove);
+  int city_id;
+
+  if (idx < 0) {
+    return NULL;
+  }
+
+  city_id = pplayer->wonders[idx];
 
   fc_assert_ret_val(NULL != pplayer, NULL);
   fc_assert_ret_val(is_wonder(pimprove), NULL);
