@@ -105,8 +105,8 @@ bv_extras get_tile_infrastructure_set(const struct tile *ptile,
 
   BV_CLR_ALL(pspresent);
 
-  extra_type_iterate(pextra) {
-    if (is_extra_removed_by(pextra, ERM_PILLAGE) && tile_has_extra(ptile, pextra)) {
+  extra_type_by_rmcause_iterate(ERM_PILLAGE, pextra) {
+    if (tile_has_extra(ptile, pextra)) {
       struct tile *missingset = tile_virtual_new(ptile);
       bool dependency = FALSE;
 
@@ -129,7 +129,7 @@ bv_extras get_tile_infrastructure_set(const struct tile *ptile,
         count++;
       }
     }
-  } extra_type_iterate_end;
+  } extra_type_by_rmcause_iterate_end;
 
   if (pcount) {
     *pcount = count;
@@ -766,8 +766,7 @@ int tile_move_cost_ptrs(const struct unit *punit,
 {
   const struct unit_class *pclass = utype_class(punittype);
   int cost;
-  bool cardinality_checked = FALSE;
-  bool cardinal_move BAD_HEURISTIC_INIT(FALSE);
+  signed char cardinal_move = -1;
   bool ri;
 
   /* Try to exit early for detectable conditions */
@@ -826,11 +825,11 @@ int tile_move_cost_ptrs(const struct unit *punit,
           if (proad->move_mode == RMM_FAST_ALWAYS) {
             cost = proad->move_cost;
           } else {
-            if (!cardinality_checked) {
-              cardinal_move = (ALL_DIRECTIONS_CARDINAL() || is_move_cardinal(t1, t2));
-              cardinality_checked = TRUE;
+            if (cardinal_move < 0) {
+              cardinal_move = (ALL_DIRECTIONS_CARDINAL()
+                               || is_move_cardinal(t1, t2)) ? 1 : 0;
             }
-            if (cardinal_move) {
+            if (cardinal_move > 0) {
               cost = proad->move_cost;
             } else {
               switch (proad->move_mode) {
@@ -870,10 +869,11 @@ int tile_move_cost_ptrs(const struct unit *punit,
   }
 
   if (terrain_control.pythagorean_diagonal) {
-    if (!cardinality_checked) {
-      cardinal_move = (ALL_DIRECTIONS_CARDINAL() || is_move_cardinal(t1, t2));
+    if (cardinal_move < 0) {
+      cardinal_move = (ALL_DIRECTIONS_CARDINAL()
+                       || is_move_cardinal(t1, t2)) ? 1 : 0;
     }
-    if (!cardinal_move) {
+    if (cardinal_move == 0) {
       return cost * 181 >> 7; /* == (int) (cost * 1.41421356f) if cost < 99 */
     }
   }
@@ -953,7 +953,7 @@ bool is_normal_map_pos(int x, int y)
   returned.
 
   Note, we need to leave x and y with sane values even in the unreal case.
-  Some callers may for instance call nearest_real_pos on these values.
+  Some callers may for instance call nearest_real_tile() on these values.
 **************************************************************************/
 bool normalize_map_pos(int *x, int *y)
 {
@@ -1582,7 +1582,7 @@ bool startpos_is_excluding(const struct startpos *psp)
 ****************************************************************************/
 const struct nation_hash *startpos_raw_nations(const struct startpos *psp)
 {
-  fc_assert_ret_val(NULL != psp, FALSE);
+  fc_assert_ret_val(NULL != psp, NULL);
   return psp->nations;
 }
 
