@@ -1268,7 +1268,7 @@ struct packet_ruleset_road {
   int tile_incr[O_LAST];
   int tile_bonus[O_LAST];
   enum road_compat compat;
-  bv_roads integrates;
+  bv_max_extras integrates;
   bv_road_flags flags;
 };
 
