@@ -836,7 +836,7 @@ bool research_goal_tech_req(const struct research *presearch,
 }
 
 /****************************************************************************
-  Function to determine cost for technology.  The equation is determined
+  Function to determine cost for technology. The equation is determined
   from game.info.tech_cost_style and game.info.tech_leakage.
 
   tech_cost_style:
@@ -869,7 +869,7 @@ bool research_goal_tech_req(const struct research *presearch,
                          of normal players (human and AI) which already know
                          the tech.
 
-  At the end we multiply by the sciencebox value, as a percentage.  The
+  At the end we multiply by the sciencebox value, as a percentage. The
   cost can never be less than 1.
 
   'presearch' may be NULL in which case a simplified result is returned
@@ -883,6 +883,10 @@ int research_total_bulbs_required(const struct research *presearch,
   double base_cost, total_cost;
   double leak = 0.0;
 
+  if (valid_advance_by_number(tech) == NULL) {
+    return 0;
+  }
+
   if (!loss_value
       && NULL != presearch
       && !is_future_tech(tech)
@@ -1336,10 +1340,25 @@ int recalculate_techs_researched(const struct research *presearch)
   int techs = 1; /* A_NONE known, and not part of below iteration */
 
   advance_iterate(A_FIRST, t) {
-    if (research_invention_state(presearch, advance_number(t)) == TECH_KNOWN) {
+    if (valid_advance(t) != NULL
+        && research_invention_state(presearch, advance_number(t)) == TECH_KNOWN) {
       techs++;
     }
   } advance_iterate_end;
 
   return techs + presearch->future_tech;
 }
+
+/****************************************************************************
+  Is this research group going to research some Future Tech next?
+****************************************************************************/
+bool research_future_next(const struct research *presearch)
+{
+  advance_index_iterate(A_FIRST, i) {
+    if (research_invention_state(presearch, i) != TECH_KNOWN) {
+      return FALSE;
+    }
+  } advance_index_iterate_end;
+
+  return TRUE;
+}
