@@ -147,7 +147,7 @@ enum unit_airlift_result
       if (0 >= pdest_city->airlift
           && !(game.info.airlifting_style & AIRLIFTING_UNLIMITED_DEST)) {
         /* The destination cannot support airlifted units for this turn
-         * (maybe already airlifed or no airport).
+         * (maybe already airlifted or no airport).
          * See also do_airline() in server/unittools.h. */
         return AR_DST_NO_FLIGHTS;
       } /* else continue */
@@ -1414,21 +1414,74 @@ struct unit *unit_occupies_tile(const struct tile *ptile,
 }
 
 /**************************************************************************
-  Is this square controlled by the pplayer?
+  Is this square controlled by the pplayer? Function to be used on
+  server side only.
 
-  Here "is_my_zoc" means essentially a square which is *not* adjacent to an
+  Here "plr zoc" means essentially a square which is *not* adjacent to an
+  enemy unit (that has a ZOC) on a terrain that has zoc rules.
+**************************************************************************/
+bool is_plr_zoc_srv(const struct player *pplayer, const struct tile *ptile0)
+{
+  square_iterate(ptile0, 1, ptile) {
+    struct terrain *pterrain;
+    struct city *pcity;
+
+    pterrain = tile_terrain(ptile);
+    if (terrain_has_flag(pterrain, TER_NO_ZOC)) {
+      continue;
+    }
+
+    pcity = tile_non_allied_city(ptile, pplayer);
+    if (pcity != NULL) {
+      if (unit_list_size(ptile->units) > 0) {
+        /* Occupied enemy city, it doesn't matter if units inside have
+         * UTYF_NOZOC or not. */
+        return FALSE;
+      }
+    } else {
+      unit_list_iterate(ptile->units, punit) {
+        if (!pplayers_allied(unit_owner(punit), pplayer)
+            && !unit_has_type_flag(punit, UTYF_NOZOC)
+            && !unit_transported_server(punit)) {
+          bool hidden = FALSE;
+
+          /* We do NOT check the possibility that player is allied with an extra owner,
+           * and should thus see inside the extra.
+           * This is to avoid the situation where having an alliance with third player
+           * suddenly causes ZoC from a unit that would not cause it without the alliance. */
+          extra_type_list_iterate(unit_class_get(punit)->cache.hiding_extras, pextra) {
+            if (tile_has_extra(ptile, pextra)) {
+              hidden = TRUE;
+              break;
+            }
+          } extra_type_list_iterate_end;
+
+          if (!hidden) {
+            return FALSE;
+          }
+        }
+      } unit_list_iterate_end;
+    }
+  } square_iterate_end;
+
+  return TRUE;
+}
+
+/**************************************************************************
+  Is this square controlled by the pplayer? Function to be used on
+  client side only.
+
+  Here "plr zoc" means essentially a square which is *not* adjacent to an
   enemy unit (that has a ZOC) on a terrain that has zoc rules.
 
-  Since this function is also used in the client, it has to deal with some
-  client-specific features, like FoW and the fact that the client cannot 
+  Since this function is used in the client, it has to deal with some
+  client-specific features, like FoW and the fact that the client cannot
   see units inside enemy cities.
 **************************************************************************/
-bool is_my_zoc(const struct player *pplayer, const struct tile *ptile0)
+bool is_plr_zoc_client(const struct player *pplayer, const struct tile *ptile0)
 {
-  struct terrain *pterrain;
-  bool srv = is_server();
-
   square_iterate(ptile0, 1, ptile) {
+    struct terrain *pterrain;
     struct city *pcity;
 
     pterrain = tile_terrain(ptile);
@@ -1439,27 +1492,18 @@ bool is_my_zoc(const struct player *pplayer, const struct tile *ptile0)
 
     pcity = tile_non_allied_city(ptile, pplayer);
     if (pcity != NULL) {
-      if ((srv && unit_list_size(ptile->units) > 0)
-          || (!srv && (pcity->client.occupied
-                       || TILE_KNOWN_UNSEEN == tile_get_known(ptile, pplayer)))) {
+      if (pcity->client.occupied
+          || TILE_KNOWN_UNSEEN == tile_get_known(ptile, pplayer)) {
         /* Occupied enemy city, it doesn't matter if units inside have
          * UTYF_NOZOC or not. Fogged city is assumed to be occupied. */
         return FALSE;
       }
     } else {
       unit_list_iterate(ptile->units, punit) {
-        if (srv) {
-          if (!unit_transported_server(punit)
-              && !pplayers_allied(unit_owner(punit), pplayer)
-              && !unit_has_type_flag(punit, UTYF_NOZOC)) {
-            return FALSE;
-          }
-        } else {
-          if (!unit_transported_client(punit)
-              && !pplayers_allied(unit_owner(punit), pplayer)
-              && !unit_has_type_flag(punit, UTYF_NOZOC)) {
-            return FALSE;
-          }
+        if (!unit_transported_client(punit)
+            && !pplayers_allied(unit_owner(punit), pplayer)
+            && !unit_has_type_flag(punit, UTYF_NOZOC)) {
+          return FALSE;
         }
       } unit_list_iterate_end;
     }
