@@ -1538,7 +1538,11 @@ static void create_vision_dependencies(void)
 void give_shared_vision(struct player *pfrom, struct player *pto)
 {
   bv_player save_vision[player_slot_count()];
-  if (pfrom == pto) return;
+
+  if (pfrom == pto) {
+    return;
+  }
+
   if (gives_shared_vision(pfrom, pto)) {
     log_error("Trying to give shared vision from %s to %s, "
               "but that vision is already given!",
@@ -1719,6 +1723,50 @@ static void ocean_to_land_fix_rivers(struct tile *ptile)
   } cardinal_adjc_iterate_end;
 }
 
+/**************************************************************************
+  Bounce one unit from tile on terrain change.
+**************************************************************************/
+static void terrain_change_bounce_single_unit(struct unit *punit,
+                                              struct tile *from)
+{
+  bool unit_alive = TRUE;
+
+  /* Look for a nearby safe tile */
+  adjc_iterate(from, ptile2) {
+    if (can_unit_exist_at_tile(punit, ptile2)
+        && !is_non_allied_unit_tile(ptile2, unit_owner(punit))
+        && !is_non_allied_city_tile(ptile2, unit_owner(punit))) {
+      log_verbose("Moved %s %s due to changing terrain at (%d,%d).",
+                  nation_rule_name(nation_of_unit(punit)),
+                  unit_rule_name(punit), TILE_XY(unit_tile(punit)));
+      notify_player(unit_owner(punit), unit_tile(punit),
+                    E_UNIT_RELOCATED, ftc_server,
+                    _("Moved your %s due to changing terrain."),
+                    unit_link(punit));
+
+      unit_alive = unit_move(punit, ptile2, 0, NULL, FALSE);
+      if (unit_alive && punit->activity == ACTIVITY_SENTRY) {
+        unit_activity_handling(punit, ACTIVITY_IDLE);
+      }
+      break;
+    }
+  } adjc_iterate_end;
+
+  if (unit_alive && unit_tile(punit) == from) {
+    /* If we get here we could not move punit. */
+
+    /* Try to bounce transported units. */
+    if (0 < get_transporter_occupancy(punit)) {
+      struct unit_list *pcargo_units;
+
+      pcargo_units = unit_transport_cargo(punit);
+      unit_list_iterate_safe(pcargo_units, pcargo) {
+        terrain_change_bounce_single_unit(pcargo, from);
+      } unit_list_iterate_safe_end;
+    }
+  }
+}
+
 /****************************************************************************
   Helper function for bounce_units_on_terrain_change() that checks units
   on a single tile.
@@ -1726,31 +1774,14 @@ static void ocean_to_land_fix_rivers(struct tile *ptile)
 static void check_units_single_tile(struct tile *ptile)
 {
   unit_list_iterate_safe(ptile->units, punit) {
-    bool unit_alive = TRUE;
+    int id = punit->id;
 
-    if (unit_tile(punit) == ptile
-        && !unit_transported(punit)
+    /* Top-level transports only. Each handle their own cargo */
+    if (!unit_transported(punit)
         && !can_unit_exist_at_tile(punit, ptile)) {
-      /* look for a nearby safe tile */
-      adjc_iterate(ptile, ptile2) {
-        if (can_unit_exist_at_tile(punit, ptile2)
-            && !is_non_allied_unit_tile(ptile2, unit_owner(punit))
-            && !is_non_allied_city_tile(ptile2, unit_owner(punit))) {
-          log_verbose("Moved %s %s due to changing terrain at (%d,%d).",
-                      nation_rule_name(nation_of_unit(punit)),
-                      unit_rule_name(punit), TILE_XY(unit_tile(punit)));
-          notify_player(unit_owner(punit), unit_tile(punit),
-                        E_UNIT_RELOCATED, ftc_server,
-                        _("Moved your %s due to changing terrain."),
-                        unit_link(punit));
-          unit_alive = unit_move(punit, ptile2, 0, NULL, FALSE);
-          if (unit_alive && punit->activity == ACTIVITY_SENTRY) {
-            unit_activity_handling(punit, ACTIVITY_IDLE);
-          }
-          break;
-	}
-      } adjc_iterate_end;
-      if (unit_alive && unit_tile(punit) == ptile) {
+      terrain_change_bounce_single_unit(punit, ptile);
+
+      if (unit_is_alive(id) && unit_tile(punit) == ptile) {
         /* If we get here we could not move punit. */
         log_verbose("Disbanded %s %s due to changing land "
                     " to sea at (%d, %d).",
@@ -2246,32 +2277,42 @@ void map_claim_base(struct tile *ptile, struct extra_type *pextra,
                     struct player *powner, struct player *ploser)
 {
   struct base_type *pbase;
+  bv_player *could_see_unit = NULL;
   int units_num = 0;
-  bv_player *could_see_unit BAD_HEURISTIC_INIT(NULL);
+  int ul_size;
 
   if (!tile_has_extra(ptile, pextra)) {
     return;
   }
 
   if (pextra->eus != EUS_NORMAL) {
-    int i = 0;
+    ul_size = unit_list_size(ptile->units);
+  } else {
+    ul_size = 0;
+  }
 
-    units_num = unit_list_size(ptile->units);
+  int stored_units[ul_size + 1];
 
-    if (units_num > 0) {
-      could_see_unit = fc_malloc(sizeof(*could_see_unit) * units_num);
+  if (ul_size > 0) {
+    int i;
 
-      unit_list_iterate(ptile->units, aunit) {
-        BV_CLR_ALL(could_see_unit[i]);
-        players_iterate(aplayer) {
-          if (can_player_see_unit(aplayer, aunit)) {
-            BV_SET(could_see_unit[i], player_index(aplayer));
-          }
-        } players_iterate_end;
-        i++;
-      } unit_list_iterate_end;
-    } else {
-      could_see_unit = NULL; /* To keep compiler happy */
+    could_see_unit = fc_malloc(sizeof(*could_see_unit) * ul_size);
+
+    unit_list_iterate(ptile->units, aunit) {
+      stored_units[units_num++] = aunit->id;
+    } unit_list_iterate_end;
+
+    fc_assert(units_num == ul_size);
+
+    for (i = 0; i < units_num; i++) {
+      struct unit *aunit = game_unit_by_number(stored_units[i]);
+
+      BV_CLR_ALL(could_see_unit[i]);
+      players_iterate(aplayer) {
+        if (can_player_see_unit(aplayer, aunit)) {
+          BV_SET(could_see_unit[i], player_index(aplayer));
+        }
+      } players_iterate_end;
     }
   }
 
@@ -2323,14 +2364,11 @@ void map_claim_base(struct tile *ptile, struct extra_type *pextra,
   }
 
   if (units_num > 0) {
-    int i = 0;
+    int i;
 
-    fc_assert(pextra->eus != EUS_NORMAL);
+    for (i = 0; i < units_num; i++) {
+      struct unit *aunit = game_unit_by_number(stored_units[i]);
 
-    /* TODO: Is it really safe, after all the potential effects above
-     * function calls can have, to assume that the tile has the same units
-     * in the same order as when could_see_unit[] was first created? */
-    unit_list_iterate(ptile->units, aunit) {
       players_iterate(aplayer) {
         if (can_player_see_unit(aplayer, aunit)) {
           if (!BV_ISSET(could_see_unit[i], player_index(aplayer))) {
@@ -2342,8 +2380,7 @@ void map_claim_base(struct tile *ptile, struct extra_type *pextra,
           }
         }
       } players_iterate_end;
-      i++;
-    } unit_list_iterate_end;
+    }
 
     free(could_see_unit);
   }
