@@ -258,7 +258,7 @@ static bool manual_command(void)
     switch (manuals) {
     case MANUAL_SETTINGS:
       /* TRANS: markup ... Freeciv version ... markup */
-      fprintf(doc, _("%sFreeciv %s server options%s\n\n"), TITLE_BEGIN,
+      fprintf(doc, _("%sFreeciv %s server settings%s\n\n"), TITLE_BEGIN,
               VERSION_STRING, TITLE_END);
       settings_iterate(SSET_ALL, pset) {
         char buf[256];
@@ -305,24 +305,26 @@ static bool manual_command(void)
           {
             const char *value;
 
-            fprintf(doc, "\n<p class=\"bounds\">%s</p>",
+            fprintf(doc, "\n<p class=\"bounds\">%s</p><ul>",
                     _("Possible values:"));
             for (i = 0; (value = setting_enum_val(pset, i, FALSE)); i++) {
-              fprintf(doc, "\n<p class=\"bounds\"><li/> %s: \"%s\"</p>",
+              fprintf(doc, "\n<li><p class=\"bounds\"> %s: \"%s\"</p>",
                       value, setting_enum_val(pset, i, TRUE));
             }
+            fprintf(doc, "</ul>\n");
           }
           break;
         case SST_BITWISE:
           {
             const char *value;
 
-            fprintf(doc, "\n<p class=\"bounds\">%s</p>",
+            fprintf(doc, "\n<p class=\"bounds\">%s</p><ul>",
                     _("Possible values (option can take any number of these):"));
             for (i = 0; (value = setting_bitwise_bit(pset, i, FALSE)); i++) {
-              fprintf(doc, "\n<p class=\"bounds\"><li/> %s: \"%s\"</p>",
+              fprintf(doc, "\n<li><p class=\"bounds\"> %s: \"%s\"</p>",
                       value, setting_bitwise_bit(pset, i, TRUE));
             }
+            fprintf(doc, "</ul>\n");
           }
           break;
         case SST_BOOL:
@@ -570,7 +572,9 @@ static bool manual_command(void)
           } requirement_vector_iterate_end;
         }
 
-        fprintf(doc, "</td>\n<td>%s</td>\n</tr>\n\n", buf);
+        fprintf(doc,
+                "</td>\n<td>%s</td>\n</tr><tr><td colspan=\"5\"><hr></td></tr>\n\n",
+                buf);
       } improvement_iterate_end;
 
       fprintf(doc, "</table>");
