@@ -93,10 +93,6 @@ enum fc_tristate fc_tristate_or(enum fc_tristate one, enum fc_tristate two);
 
 #define FC_INT_TO_PTR(i) ((void *) (intptr_t) (i))
 #define FC_PTR_TO_INT(p) ((int) (intptr_t) (p))
-#define FC_UINT_TO_PTR(u) ((void *) (intptr_t) (u))
-#define FC_PTR_TO_UINT(p) ((unsigned int) (intptr_t) (p))
-#define FC_SIZE_TO_PTR(s) ((void *) (intptr_t) (s))
-#define FC_PTR_TO_SIZE(p) ((size_t) (intptr_t) (p))
 
 /****************************************************************************
   Used to initialize an array 'a' of size 'size' with value 'val' in each
@@ -206,7 +202,7 @@ void switch_lang(const char *lang);
 
 void dont_run_as_root(const char *argv0, const char *fallback);
 
-/*** matching prefixes: ***/
+/*** Matching prefixes: ***/
 
 enum m_pre_result {
   M_PRE_EXACT,		/* matches with exact length */
